# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
#
# Get a list of all Oracle uses that use the default profile
#
require_relative '../puppet_x/enterprisemodules/ora_secured/facts'

ora_secured_fact('access_to_aud')                   { "select distinct grantee as name from dba_tab_privs where table_name='AUD$'" }
ora_secured_fact('accounts_with_default_passwords') { 'select distinct username as name from dba_users_with_defpwd' }
ora_secured_fact('any_privileges')                  { "select distinct privilege as name from dba_sys_privs where privilege like '%ANY%'" }
ora_secured_fact('users_with_admin_grants')         { "select grantee||';'||privilege as name from dba_sys_privs, dba_users where admin_option='YES' and grantee = username and oracle_maintained = 'N'" }
ora_secured_fact('roles_with_admin_grants')         { "select grantee||';'||privilege as name from dba_sys_privs, dba_roles where admin_option='YES' and grantee = role and oracle_maintained = 'N'" }
ora_secured_fact('profiles')                        { 'select distinct profile as name from dba_users' }
ora_secured_fact('users_roles')                     { 'select username as name from dba_users union select role as name from dba_roles' }
ora_secured_fact('users_with_default_profile')      { "select distinct username as name from dba_users where profile='DEFAULT' and account_status='OPEN' and ORACLE_MAINTAINED = 'N'" }
ora_secured_fact('users_with_external_password')    { "select distinct username as name from dba_users where password='EXTERNAL'" }
ora_secured_fact('non_maintained_users')            { "select distinct username as name from dba_users where oracle_maintained='N'" }
ora_secured_fact('non_maintained_roles')            { "select distinct role as name from dba_roles where oracle_maintained='N'" }
ora_secured_fact('non_maintained_users_roles')      { "select distinct username as name from dba_users where oracle_maintained='N' union select distinct role as name from dba_roles where oracle_maintained='N'" }
ora_secured_fact('global_profiles')                 { "select distinct profile as name from dba_users where profile like 'C##%'" }
