#
# ora_secured::controls::access_to_dbms_software_files_and_directories_must_not_be_granted_to_unauthorized_users
#
# @summary For UNIX Systems:
# log on using the Oracle software owner account and enter the command:
# 
#   umask
# 
# If the value returned is 022 or more restrictive, this is not a finding.
# 
# If the value returned is less restrictive than 022, this is a finding.
# 
# The first number sets the mask for user/owner file permissions. The second number sets the mask for group file permissions. The third number sets file permission mask for other users. The list below shows the available settings:
# 
# 0 = read/write/execute
# 1 = read/write
# 2 = read/execute
# 3 = read
# 4 = write/execute
# 5 = write
# 6 = execute
# 7 = no permissions
# 
# Setting the umask to 022 effectively sets files for user/owner to read/write, group to read and other to read. Directories are set for user/owner to read/write/execute, group to read/execute and other to read/execute.
# 
# For Windows Systems:
# Review the permissions that control access to the Oracle installation software directories (e.g. \Program Files\Oracle\).
# 
# DBA accounts, the DBMS process account, the DBMS software installation/maintenance account, SA accounts if access by them is required for some operational level of support such as backups, and the host system itself require access.
# 
# Compare the access control employed with that documented in the System Security Plan.
# 
# If access controls do not match the documented requirement, this is a finding.
# 
# If access controls appear excessive without justification, this is a finding.
# 
# 
# Set the umask of the Oracle software owner account to 022. Determine the shell being used for the Oracle software owner account:
# 
#   env | grep -i shell
# 
# Startup files for each shell are as follows (located in users $HOME directory):
# 
#   C-Shell (CSH) = .cshrc
#   Bourne Shell (SH) = .profile
#   Korn Shell (KSH) = .kshrc
#   TC Shell (TCS) = .tcshrc
#   BASH Shell = .bash_profile or .bashrc
# 
# Edit the shell startup file for the account and add or modify the line:
# 
#   umask 022
# 
# Log off and logon, then enter the umask command to confirm the setting.
# 
# Note: To effect this change for all Oracle processes, a reboot of the DBMS server may be required.
# 
# For Windows Systems:
# Restrict access to the DBMS software libraries to the fewest accounts that clearly require access based on job function.
# 
# Document authorized access controls and justify any access grants that do not fall under DBA, DBMS process, ownership, or SA accounts.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::access_to_dbms_software_files_and_directories_must_not_be_granted_to_unauthorized_users: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::access_to_dbms_software_files_and_directories_must_not_be_granted_to_unauthorized_users::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `access_to_dbms_software_files_and_directories_must_not_be_granted_to_unauthorized_users` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61511
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::access_to_dbms_software_files_and_directories_must_not_be_granted_to_unauthorized_users {
  ora_secured_setup { "access_to_dbms_software_files_and_directories_must_not_be_granted_to_unauthorized_users on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
