#
# ora_secured::controls::all_use_of_privileged_accounts_must_be_audited
#
# @summary Review auditing configuration.
# If it is possible for a privileged user/role to access non-security functions or information without having the action recorded in the audit log, this is a finding.
# 
# To obtain a list of unified auditing policies that have been defined, run the query:
# SELECT unique policy_name from AUDIT_UNIFIED_POLICIES;
# 
# To obtain a list of unified auditing policies that have been enabled and the users for which it has been enabled, run the query:
# SELECT unique policy_name, user_name from AUDIT_UNIFIED_ENABLED_POLICIES;
# 
# Unless otherwise required, verify that user_name is set to 'ALL USERS' to insure that the activity of administrative users is being logged.
# 
# Configure DBMS auditing so that all use of privileged accounts is recorded in the audit log.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::all_use_of_privileged_accounts_must_be_audited: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::all_use_of_privileged_accounts_must_be_audited::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `all_use_of_privileged_accounts_must_be_audited` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61595
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::all_use_of_privileged_accounts_must_be_audited {
  ora_secured_setup { "all_use_of_privileged_accounts_must_be_audited on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
