#
# ora_secured::controls::alter_system_action_audit_is_enabled
#
# @summary The `ALTER SYSTEM` privilege allows the user to change instance settings which could impact security posture, performance or normal operation of the database.
# Additionally, the `ALTER SYSTEM` privilege may be used to run operating system commands using undocumented Oracle functionality. Enabling this unified audit action causes logging of activities that involve the exercise of this privilege, whether successful or unsuccessful, issued by the users regardless of the privileges held by the users to issue such statements.
# 
# ## Rationale
# 
# Logging and monitoring of all attempts to execute `ALTER SYSTEM` statements, whether successful or unsuccessful, may provide forensic evidence about potential suspicious/unauthorized activities. Any such activities may be a cause for further investigation. In addition, organization security policies and industry/government regulations may require logging of all user activities that involve `ALTER SYSTEM` statements.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 6.2.23
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::alter_system_action_audit_is_enabled: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::alter_system_action_audit_is_enabled::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `alter_system_action_audit_is_enabled` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::alter_system_action_audit_is_enabled () {
  $sid = $title
  ora_secured_setup { "alter_system_action_audit_is_enabled on ${title}":
    ensure => 'present',
  }

  -> ora_secured::internal::audit_option { "ALTER SYSTEM@${sid}": }
}
