#
# ora_secured::controls::app_object_owner_accnts_must_be_disabled_when_not_performing_installation_or_maint_actions
#
# @summary Run the SQL query:
# select distinct o.owner from dba_objects o, dba_users u
#  where o.owner not in
# (
#  <list of non-applicable accounts>
# )
#  and o.object_type <> 'SYNONYM'
#  and o.owner = username
#  and upper(account_status) not like '%LOCKED%';
# 
# (With respect to the list of special accounts that are excluded from this requirement, it is expected that the DBA will maintain the list to suit local circumstances, adding special accounts as necessary and removing any that are not supposed to be in use in the Oracle deployment that is under review.)
# 
# To obtain a list of users assigned DBA privileges, run the query:
# 
#   select grantee from dba_role_privs where granted_role = 'DBA';
# 
# If any records are returned, then verify the account is an authorized application object owner account or a default account installed to support an Oracle product.
# 
# Verify that any objects owned by custom DBA accounts are for the personal use of that DBA.
# 
# If any objects are used to support applications or any functions other than DBA functions, this is a finding.
# 
# Any unauthorized object owner accounts are not a finding under this check as they are noted as findings under check O121-C2-011000.
# 
# Any other accounts listed are a finding.
# 
# Disable any application object owner accounts.
# 
# From SQL*Plus:
#   alter user [username] account lock;
# 
# Enable application object owner accounts only for installation and maintenance.
# 
# DBAs are special purpose accounts and do not require disabling although they may own objects.
# 
# For application objects that require routine maintenance, e.g. index objects, to maintain performance, consider allowing a special purpose account to own the index or enable the application owner account for the duration of the routine maintenance function only.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::app_object_owner_accnts_must_be_disabled_when_not_performing_installation_or_maint_actions: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::app_object_owner_accnts_must_be_disabled_when_not_performing_installation_or_maint_actions::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `app_object_owner_accnts_must_be_disabled_when_not_performing_installation_or_maint_actions` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61467
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::app_object_owner_accnts_must_be_disabled_when_not_performing_installation_or_maint_actions {
  ora_secured_setup { "app_object_owner_accnts_must_be_disabled_when_not_performing_installation_or_maint_actions on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
