#
# ora_secured::controls::app_user_priv_assignment_must_be_reviewed_monthly_or_more_frequently_to_ensure_compliance_with_le
#
# @summary Review policy, procedures and implementation evidence to determine if periodic reviews of user privileges by the ISSO are being performed.
# Evidence may consist of email or other correspondence that acknowledges receipt of periodic reports and notification of review between the DBA and ISSO or other auditors as assigned.
# 
# If policy and procedures are incomplete or no evidence of implementation exists, this is a finding.
# 
# Develop, document and implement policy and procedures for periodic review of database user accounts and privilege assignments.
# 
# Include methods to provide evidence of review in the procedures to verify reviews occur in accordance with the procedures.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::app_user_priv_assignment_must_be_reviewed_monthly_or_more_frequently_to_ensure_compliance_with_le: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::app_user_priv_assignment_must_be_reviewed_monthly_or_more_frequently_to_ensure_compliance_with_le::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `app_user_priv_assignment_must_be_reviewed_monthly_or_more_frequently_to_ensure_compliance_with_le` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61455
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::app_user_priv_assignment_must_be_reviewed_monthly_or_more_frequently_to_ensure_compliance_with_le {
  ora_secured_setup { "app_user_priv_assignment_must_be_reviewed_monthly_or_more_frequently_to_ensure_compliance_with_le on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
