#
# ora_secured::controls::audit_trail_data_must_be_retained_for_at_least_one_year
#
# @summary Review and verify the implementation of an audit trail retention policy.
# Verify that audit data is maintained for a minimum of one year.
# 
# If audit data is not maintained for a minimum of one year, this is a finding.
# 
# Develop, document and implement an audit retention policy and procedures.
# 
# It is recommended that the most recent thirty days of audit logs remain available online.
# 
# After thirty days, the audit logs may be maintained off-line.
# 
# Online maintenance provides for a more timely capability and inclination to investigate suspicious activity.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::audit_trail_data_must_be_retained_for_at_least_one_year: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::audit_trail_data_must_be_retained_for_at_least_one_year::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `audit_trail_data_must_be_retained_for_at_least_one_year` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61409
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::audit_trail_data_must_be_retained_for_at_least_one_year {
  ora_secured_setup { "audit_trail_data_must_be_retained_for_at_least_one_year on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
