#
# ora_secured::controls::audit_trail_data_must_be_reviewed_daily_or_more_frequently
#
# @summary If the database being reviewed is not a production database, this check is not a finding.
# Review policy and procedures documented or noted in the System Security plan as well as evidence of implementation for daily audit trail monitoring.
# 
# If policy and procedures are not documented or evidence of implementation is not available, this is a finding.
# 
# Develop, document and implement policy and procedures to monitor audit trail data daily.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::audit_trail_data_must_be_reviewed_daily_or_more_frequently: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::audit_trail_data_must_be_reviewed_daily_or_more_frequently::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `audit_trail_data_must_be_reviewed_daily_or_more_frequently` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61457
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::audit_trail_data_must_be_reviewed_daily_or_more_frequently {
  ora_secured_setup { "audit_trail_data_must_be_reviewed_daily_or_more_frequently on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
