#
# ora_secured::controls::be_prot_frm_unauth_acc_by_devs_on_shared_prod_dev_host_syss
#
# @summary Identify whether any hosts contain both development and production databases.
# If no hosts contain both production and development databases, this is NA.
# 
# For any host containing both a development and a production database, determine if developers have been granted elevated privileges on the production database or on the OS.  If they have, ask for documentation that shows these accounts have formal approval and risk acceptance. If this documentation does not exist, this is a finding.
# 
# If developer accounts exist with the right to create and maintain tables (or other database objects) in production tablespaces, this is a finding.
# 
# (Where applicable, to check the number of instances on the host machine, check the /etc/oratab.  The /etc/oratab file is updated by the Oracle Installer when the database is installed when the root.sh file is executed.  Each line in the represents an ORACLE_SID:ORACLE_HOME:Y or N.  The ORACLE_SID and ORACLE_HOME are self-explanatory.  The Y or N signals the DBSTART program to automatically start or not start that specific instance when the machine is restarted.  Check with the system owner and application development team to see what each entry represents.  If a system is deemed to be a production system, review the system for development users.)
# 
# Restrict developer privileges to production objects to only objects and data where those privileges are required and authorized.  Document the approval and risk acceptance.
# 
# Consider using separate accounts for a person's developer duties and production duties.  At a minimum, use separate roles for developer privileges and production privileges.
# 
# If developers need the ability to create and maintain tables (or other database objects) as part of their development activities, provide dedicated tablespaces, and revoke any rights that allowed them to use production tablespaces for this purpose.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::be_prot_frm_unauth_acc_by_devs_on_shared_prod_dev_host_syss: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::be_prot_frm_unauth_acc_by_devs_on_shared_prod_dev_host_syss::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `be_prot_frm_unauth_acc_by_devs_on_shared_prod_dev_host_syss` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61587
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::be_prot_frm_unauth_acc_by_devs_on_shared_prod_dev_host_syss {
  ora_secured_setup { "be_prot_frm_unauth_acc_by_devs_on_shared_prod_dev_host_syss on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
