#
# ora_secured::controls::be_protected_from_unauthorized_access_by_developers
#
# @summary Check the production system to ensure no developer accounts have rights to modify the production database structure or alter production data.
# If developer accounts with these rights exist, ask for documentation that shows these accounts have formal approval and risk acceptance. If this documentation does not exist, this is a finding.
# 
# If developer accounts exist with the right to create and maintain tables (or other database objects) in production tablespaces, this is a finding.
# 
# Restrict developer privileges to production objects to only objects and data where those privileges are required and authorized.  Document the approval and risk acceptance.
# 
# Consider using separate accounts for a person's developer duties and production duties.  At a minimum, use separate roles for developer privileges and production privileges.
# 
# If developers need the ability to create and maintain tables (or other database objects) as part of their development activities, provide dedicated tablespaces, and revoke any rights that allowed them to use production tablespaces for this purpose.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::be_protected_from_unauthorized_access_by_developers: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::be_protected_from_unauthorized_access_by_developers::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `be_protected_from_unauthorized_access_by_developers` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61585
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::be_protected_from_unauthorized_access_by_developers {
  ora_secured_setup { "be_protected_from_unauthorized_access_by_developers on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
