#
# ora_secured::controls::conduct_backups_of_sys_level_info_per_org_def_frequency_that_is_consistent_with_recovery_time_and
#
# @summary Review DBMS and OS backup configuration to determine that system-level data is backed up in according with organization-defined frequency.
# If the system-level data of the DBMS is not backed up to the organization-defined frequency, this is a finding.
# 
# Utilize DBMS, OS, or third-party product(s) to meet the requirement of backing up system data according to the organization-defined frequency.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::conduct_backups_of_sys_level_info_per_org_def_frequency_that_is_consistent_with_recovery_time_and: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::conduct_backups_of_sys_level_info_per_org_def_frequency_that_is_consistent_with_recovery_time_and::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `conduct_backups_of_sys_level_info_per_org_def_frequency_that_is_consistent_with_recovery_time_and` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61701
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::conduct_backups_of_sys_level_info_per_org_def_frequency_that_is_consistent_with_recovery_time_and {
  ora_secured_setup { "conduct_backups_of_sys_level_info_per_org_def_frequency_that_is_consistent_with_recovery_time_and on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
