#
# ora_secured::controls::connss_by_mid_tr_web_and_app_syss_to_orcl_dbms_frm_a_dmz_or_ext_netw_must_be_encrpted
#
# @summary Review the System Security Plan for remote applications that access and use the database.
# For each remote application or application server, determine whether communications between it and the DBMS are encrypted. If any are not encrypted, this is a finding.
# 
# Configure communications between the DBMS and remote applications/application servers to use DoD-approved encryption.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::connss_by_mid_tr_web_and_app_syss_to_orcl_dbms_frm_a_dmz_or_ext_netw_must_be_encrpted: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::connss_by_mid_tr_web_and_app_syss_to_orcl_dbms_frm_a_dmz_or_ext_netw_must_be_encrpted::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `connss_by_mid_tr_web_and_app_syss_to_orcl_dbms_frm_a_dmz_or_ext_netw_must_be_encrpted` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61447
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::connss_by_mid_tr_web_and_app_syss_to_orcl_dbms_frm_a_dmz_or_ext_netw_must_be_encrpted {
  ora_secured_setup { "connss_by_mid_tr_web_and_app_syss_to_orcl_dbms_frm_a_dmz_or_ext_netw_must_be_encrpted on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
