#
# ora_secured::controls::creds_strd_and_used_by_dbms_to_acc_rmt_dbs_or_apps_must_be_auth_and_rstrcted_to_auth_users
#
# @summary Review the list of defined database links generated from the DBMS.
# Compare to the list in the System Security Plan with the DBA.
# 
# If no database links are listed in the database and in the System Security Plan, this check is not a finding.
# 
# If any database links are defined in the DBMS, verify the authorization for the definition in the System Security Plan.
# 
# If any database links exist that are not authorized or not listed in the System Security Plan, this is a finding.
# 
# Grant access to database links to authorized users or applications only.
# 
# Document all database links access authorizations in the System Security Plan.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::creds_strd_and_used_by_dbms_to_acc_rmt_dbs_or_apps_must_be_auth_and_rstrcted_to_auth_users: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::creds_strd_and_used_by_dbms_to_acc_rmt_dbs_or_apps_must_be_auth_and_rstrcted_to_auth_users::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `creds_strd_and_used_by_dbms_to_acc_rmt_dbs_or_apps_must_be_auth_and_rstrcted_to_auth_users` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61507
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::creds_strd_and_used_by_dbms_to_acc_rmt_dbs_or_apps_must_be_auth_and_rstrcted_to_auth_users {
  ora_secured_setup { "creds_strd_and_used_by_dbms_to_acc_rmt_dbs_or_apps_must_be_auth_and_rstrcted_to_auth_users on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
