#
# ora_secured::controls::database_recovery_procedures_must_be_developed_documented_implemented_and_periodically_tested
#
# @summary Review the testing and verification procedures documented in the system documentation.
# Review evidence of implementation of testing and verification procedures by reviewing logs from backup and recovery implementation. Logs may be in electronic form or hardcopy and may include email or other notification.
# 
# If testing and verification of backup and recovery procedures is not documented in the system documentation, this is a finding.
# 
# If evidence of testing and verification of backup and recovery procedures does not exist, this is a finding.
# 
# Develop, document, and implement testing and verification procedures for database backup and recovery. Include requirements for documenting database backup and recovery testing and verification activities in the procedures.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::database_recovery_procedures_must_be_developed_documented_implemented_and_periodically_tested: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::database_recovery_procedures_must_be_developed_documented_implemented_and_periodically_tested::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `database_recovery_procedures_must_be_developed_documented_implemented_and_periodically_tested` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61697
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::database_recovery_procedures_must_be_developed_documented_implemented_and_periodically_tested {
  ora_secured_setup { "database_recovery_procedures_must_be_developed_documented_implemented_and_periodically_tested on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
