#
# ora_secured::controls::db_sw_apps_and_config_files_must_be_mon_to_disc_unauth_changes
#
# @summary Review monitoring procedures and implementation evidence to verify that monitoring of changes to database software libraries, related applications, and configuration files is done.
# Verify that the list of files and directories being monitored is complete. If monitoring does not occur or is not complete, this is a finding.
# 
# Implement procedures to monitor for unauthorized changes to DBMS software libraries, related software application libraries, and configuration files. If a third-party automated tool is not employed, an automated job that reports file information on the directories and files of interest and compares them to the baseline report for the same will meet the requirement.
# 
# File hashes or checksums should be used for comparisons since file dates may be manipulated by malicious users. 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::db_sw_apps_and_config_files_must_be_mon_to_disc_unauth_changes: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::db_sw_apps_and_config_files_must_be_mon_to_disc_unauth_changes::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `db_sw_apps_and_config_files_must_be_mon_to_disc_unauth_changes` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61867
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::db_sw_apps_and_config_files_must_be_mon_to_disc_unauth_changes {
  ora_secured_setup { "db_sw_apps_and_config_files_must_be_mon_to_disc_unauth_changes on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
