#
# ora_secured::controls::dba_os_accnts_must_be_grnted_only_those_host_sys_privs_necessary_for_admin_of_dbms
#
# @summary Review host system privileges assigned to the Oracle DBA group and all individual Oracle DBA accounts.
# Note: do not include the Oracle software installation account in any results for this check.
# 
# For UNIX systems (as root):
# cat /etc/group | grep -i dba
# groups root
# 
# If "root" is returned in the first list, this is a finding.
# 
# If any accounts listed in the first list are also listed in the second list, this is a finding.
# 
# Investigate any user account group memberships other than DBA or root groups that are returned by the following command (also as root):
# 
# groups [dba user account]
# 
# Replace [dba user account] with the user account name of each DBA account.
# 
# If individual DBA accounts are assigned to groups that grant access or privileges for purposes other than DBA responsibilities, this is a finding.
# 
# For Windows Systems (click or select):
# Start / Settings / Control Panel / Administrative Tools / Computer Management / Local Users and Groups / Groups / ORA_DBA
# Start / Settings / Control Panel / Administrative Tools / Computer Management / Local Users and Groups / Groups / ORA_[SID]_DBA (if present)
# 
# Note: Users assigned DBA privileges on a Windows host are granted membership in the ORA_DBA and/or ORA_[SID]_DBA groups. The ORA_DBA group grants DBA privileges to any database on the system. The ORA_[SID]_DBA groups grant DBA privileges to specific Oracle instances only.
# 
# Make a note of each user listed. For each user (click or select):
# Start / Settings / Control Panel / Administrative Tools / Computer Management / Local Users and Groups / Users / [DBA user name] / Member of
# 
# If DBA users belong to any groups other than DBA groups and the Windows Users group, this is a finding.
# 
# Examine User Rights assigned to DBA groups or group members:
# Start / Settings / Control Panel / Administrative Tools / Local Security Policy / Security Settings / Local Policies / User Rights Assignments
# 
# If any User Rights are assigned directly to the DBA group(s) or DBA user accounts, this is a finding.
# 
# Revoke all host system privileges from the DBA group accounts and DBA user accounts not required for DBMS administration.
# 
# Revoke all OS group memberships that assign excessive privileges to the DBA group accounts and DBA user accounts.
# 
# Remove any directly applied permissions or user rights from the DBA group accounts and DBA user accounts.
# 
# Document all DBA group accounts and individual DBA account-assigned privileges in the System Security Plan.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::dba_os_accnts_must_be_grnted_only_those_host_sys_privs_necessary_for_admin_of_dbms: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::dba_os_accnts_must_be_grnted_only_those_host_sys_privs_necessary_for_admin_of_dbms::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `dba_os_accnts_must_be_grnted_only_those_host_sys_privs_necessary_for_admin_of_dbms` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61537
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::dba_os_accnts_must_be_grnted_only_those_host_sys_privs_necessary_for_admin_of_dbms {
  ora_secured_setup { "dba_os_accnts_must_be_grnted_only_those_host_sys_privs_necessary_for_admin_of_dbms on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
