#
# ora_secured::controls::dbms_host_plfrm_and_other_dependent_apps_must_be_configed_in_compliance_with_applicable_stig_reqs
#
# @summary If the DBMS host being reviewed is not a production DBMS host, this check is not a finding.
# Review evidence of security hardening and auditing of the DBMS host platform with the ISSO.
# 
# If the DBMS host platform has not been hardened and received a security audit, this is a finding.
# 
# Review evidence of security hardening and auditing for all application(s) that store data in the database and all other separately configured components that access the database including web servers, application servers, report servers, etc.
# 
# If any have not been hardened and received a security audit, this is a finding.
# 
# Review evidence of security hardening and auditing for all application(s) installed on the local DBMS host where security hardening and auditing guidance exists.
# 
# If any have not been hardened and received a security audit, this is a finding.
# 
# Configure all related application components and the DBMS host platform in accordance with the applicable DoD STIG.
# 
# Regularly audit the security configuration of related applications and the host platform to confirm continued compliance with security requirements.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::dbms_host_plfrm_and_other_dependent_apps_must_be_configed_in_compliance_with_applicable_stig_reqs: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::dbms_host_plfrm_and_other_dependent_apps_must_be_configed_in_compliance_with_applicable_stig_reqs::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `dbms_host_plfrm_and_other_dependent_apps_must_be_configed_in_compliance_with_applicable_stig_reqs` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61491
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::dbms_host_plfrm_and_other_dependent_apps_must_be_configed_in_compliance_with_applicable_stig_reqs {
  ora_secured_setup { "dbms_host_plfrm_and_other_dependent_apps_must_be_configed_in_compliance_with_applicable_stig_reqs on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
