#
# ora_secured::controls::dbms_prod_app_and_data_dirs_must_be_prot_frm_devs_on_shared_prod_dev_dbms_host_syss
#
# @summary If the DBMS or DBMS host is not shared by production and development activities, this check is not a finding.
# Review OS DBA group membership.
# 
# If any developer accounts, as identified in the System Security Plan, have been assigned DBA privileges, this is a finding.
# 
# Note: Though shared production/non-production DBMS installations was allowed under previous database STIG guidance, doing so may place it in violation of OS, Application, Network or Enclave STIG guidance. Ensure that any shared production/non-production DBMS installation meets STIG guidance requirements at all levels or mitigate any conflicts in STIG guidance with the AO.
# 
# Create separate DBMS host OS groups for developer and production DBAs.
# 
# Do not assign production DBA OS group membership to accounts used for development.
# 
# Remove development accounts from production DBA OS group membership.
# 
# Recommend establishing a dedicated DBMS host for production DBMS installations. A dedicated host system in this case refers to an instance of the operating system at a minimum. The operating system may reside on a virtual host machine where supported by the DBMS vendor.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::dbms_prod_app_and_data_dirs_must_be_prot_frm_devs_on_shared_prod_dev_dbms_host_syss: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::dbms_prod_app_and_data_dirs_must_be_prot_frm_devs_on_shared_prod_dev_dbms_host_syss::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `dbms_prod_app_and_data_dirs_must_be_prot_frm_devs_on_shared_prod_dev_dbms_host_syss` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61487
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::dbms_prod_app_and_data_dirs_must_be_prot_frm_devs_on_shared_prod_dev_dbms_host_syss {
  ora_secured_setup { "dbms_prod_app_and_data_dirs_must_be_prot_frm_devs_on_shared_prod_dev_dbms_host_syss on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
