#
# ora_secured::controls::dbms_software_installation_account_must_be_restricted_to_authorized_users
#
# @summary Review procedures for controlling and granting access to use of the DBMS software installation account.
# If access or use of this account is not restricted to the minimum number of personnel required, or if unauthorized access to the account has been granted, this is a finding.
# 
# Develop, document, and implement procedures to restrict use of the DBMS software installation account.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::dbms_software_installation_account_must_be_restricted_to_authorized_users: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::dbms_software_installation_account_must_be_restricted_to_authorized_users::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `dbms_software_installation_account_must_be_restricted_to_authorized_users` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61873
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::dbms_software_installation_account_must_be_restricted_to_authorized_users {
  ora_secured_setup { "dbms_software_installation_account_must_be_restricted_to_authorized_users on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
