#
# ora_secured::controls::dbms_software_libraries_must_be_periodically_backed_up
#
# @summary Review evidence of inclusion of the DBMS libraries in current backup records.
# If any DBMS library files are not included in regular backups, this is a finding.
# 
# Configure backups to include all DBMS application and third-party database application software libraries.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::dbms_software_libraries_must_be_periodically_backed_up: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::dbms_software_libraries_must_be_periodically_backed_up::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `dbms_software_libraries_must_be_periodically_backed_up` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61877
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::dbms_software_libraries_must_be_periodically_backed_up {
  ora_secured_setup { "dbms_software_libraries_must_be_periodically_backed_up on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
