#
# ora_secured::controls::dbms_symmetric_keys_must_be_prot_in_acc_with_nsa_or_nist_apprvd_key_mgmt_technology_or_procs
#
# @summary If the symmetric key management procedures and configuration settings for the DBMS are not specified in the System Security Plan, this is a finding.
# If the procedures are not followed, with evidence for audit, this is a finding.
# 
# Note:  This check does not include a review of the key management procedures for validity. Specific key management requirements may be covered under separate checks.
# 
# Implement the following for symmetric and other encryption keys:
#   -  protection from unauthorized access in transit and in storage
#   -  utilization of accepted algorithms
#   -  generation in accordance with required standards for the key's use
#   -  expiration date
#   -  continuity - key backup and recovery
#   -  key change
#   -  archival key storage (as necessary)
# 
# Details for key management requirements are provided by FIPS 140-2 key management standards available from NIST.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::dbms_symmetric_keys_must_be_prot_in_acc_with_nsa_or_nist_apprvd_key_mgmt_technology_or_procs: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::dbms_symmetric_keys_must_be_prot_in_acc_with_nsa_or_nist_apprvd_key_mgmt_technology_or_procs::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `dbms_symmetric_keys_must_be_prot_in_acc_with_nsa_or_nist_apprvd_key_mgmt_technology_or_procs` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61525
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::dbms_symmetric_keys_must_be_prot_in_acc_with_nsa_or_nist_apprvd_key_mgmt_technology_or_procs {
  ora_secured_setup { "dbms_symmetric_keys_must_be_prot_in_acc_with_nsa_or_nist_apprvd_key_mgmt_technology_or_procs on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
