#
# ora_secured::controls::dbms_when_using_pki_based_auth_must_enforce_auth_acc_to_corresponding_private_key
#
# @summary If PKI is not enabled in Oracle Database, this is not a finding.
# Review DBMS configuration to determine whether appropriate access controls exist to protect the DBMS’s private key. If strong access controls do not exist to enforce authorized access to the private key, this is a finding.
# 
# - - - - -
# The database supports authentication by using digital certificates over TLS in addition to the native encryption and data integrity capabilities of these protocols.
# 
# An Oracle Wallet is a container that is used to store authentication and signing credentials, including private keys, certificates, and trusted certificates needed by TLS. In an Oracle environment, every entity that communicates over TLS must have a wallet containing an X.509 version 3 certificate, private key, and list of trusted certificates, with the exception of Diffie-Hellman.
# 
# If the $ORACLE_HOME/network/admin/sqlnet.ora contains the following entries,  TLS is installed. (Note: This assumes that a single sqlnet.ora file, in the default location, is in use. Please see the supplemental file "Non-default sqlnet.ora configurations.pdf" for how to find multiple and/or differently located sqlnet.ora files.)
# 
# WALLET_LOCATION = (SOURCE=
#                           (METHOD = FILE) 
#                           (METHOD_DATA = 
#                            DIRECTORY=/wallet)
# 
# SSL_CIPHER_SUITES=(SSL_cipher_suiteExample)
# SSL_VERSION = 1.2
# SSL_CLIENT_AUTHENTICATION=FALSE/TRUE
# 
# Implement strong access and authentication controls to protect the database’s private key.
# 
# Configure the database to support Transport Layer Security (TLS) protocols and the Oracle Wallet to store authentication and signing credentials, including private keys.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::dbms_when_using_pki_based_auth_must_enforce_auth_acc_to_corresponding_private_key: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::dbms_when_using_pki_based_auth_must_enforce_auth_acc_to_corresponding_private_key::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `dbms_when_using_pki_based_auth_must_enforce_auth_acc_to_corresponding_private_key` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61543
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::dbms_when_using_pki_based_auth_must_enforce_auth_acc_to_corresponding_private_key {
  ora_secured_setup { "dbms_when_using_pki_based_auth_must_enforce_auth_acc_to_corresponding_private_key on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
