#
# ora_secured::controls::dbms_when_utlzng_pki_based_auth_must_validate_certificates_by_constructing_a_certification_path_w
#
# @summary If PKI is not enabled in the Oracle Database, this is not a finding.
# If all accounts are authenticated by the OS or an enterprise-level authentication/access mechanism and not by Oracle, this is not a finding.
# 
# Review DBMS configuration to verify the certificates being accepted by the DBMS have a valid certification path with status information to an accepted trust anchor.
# 
# If certification paths are not being validated back to a trust anchor, this is a finding.
# 
# - - - - -
# The database supports PKI-based authentication by using digital certificates over TLS in addition to the native encryption and data integrity capabilities of these protocols.
# 
# Oracle provides a complete PKI that is based on RSA Security, Inc., Public-Key Cryptography Standards, and which interoperates with Oracle servers and clients. The database uses a wallet that is a container that is used to store authentication and signing credentials, including private keys, certificates, and trusted certificates needed by TLS. In an Oracle environment, every entity that communicates over TLS must have a wallet containing an X.509 version 3 certificate, private key, and list of trusted certificates.
# 
# If the $ORACLE_HOME/network/admin/sqlnet.ora contains the following entries, TLS is installed. 
# 
# WALLET_LOCATION = (SOURCE=
# (METHOD = FILE) 
# (METHOD_DATA = 
# DIRECTORY=/wallet) 
# 
# SSL_CIPHER_SUITES=(SSL_cipher_suiteExample) 
# SSL_VERSION = 1.2
# SSL_CLIENT_AUTHENTICATION=TRUE
# 
# (Note: This assumes that a single sqlnet.ora file, in the default location, is in use. Please see the supplemental file "Non-default sqlnet.ora configurations.pdf" for how to find multiple and/or differently located sqlnet.ora files.)
# 
# Configure the DBMS to validate certificates by constructing a certification path with status information to an accepted trust anchor.
# 
# Configure the database to support Transport Layer Security (TLS) protocols and the Oracle Wallet to store authentication and signing credentials, including private keys.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::dbms_when_utlzng_pki_based_auth_must_validate_certificates_by_constructing_a_certification_path_w: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::dbms_when_utlzng_pki_based_auth_must_validate_certificates_by_constructing_a_certification_path_w::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `dbms_when_utlzng_pki_based_auth_must_validate_certificates_by_constructing_a_certification_path_w` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61741
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::dbms_when_utlzng_pki_based_auth_must_validate_certificates_by_constructing_a_certification_path_w {
  ora_secured_setup { "dbms_when_utlzng_pki_based_auth_must_validate_certificates_by_constructing_a_certification_path_w on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
