#
# ora_secured::controls::dbs_employed_to_write_data_to_portable_dig_med_must_use_cryptographic_mechs_to_prot_and_rstrct_ac
#
# @summary If data is written to portable media, the data must be protected and access restricted via cryptographic mechanisms.
# Review system documentation and interview DBA to determine whether data is ever written directly from Oracle to portable media.
# 
# If this is the case, and cryptographic mechanisms are not used to protect data written to portable media, this is a finding.
# 
# If all data writing from Oracle to portable media is done via intermediate files, pipes, or other non-portable resources under the control of the operating system, then this is not a finding with respect to Oracle.  (Note, however, that if encryption is not in use, it may be a finding with respect to the OS or the application that is used to perform the data transfer.)
# 
# Reconfigure processes that write to portable digital media so that they use cryptographic mechanisms to restrict access and protect the information.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::dbs_employed_to_write_data_to_portable_dig_med_must_use_cryptographic_mechs_to_prot_and_rstrct_ac: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::dbs_employed_to_write_data_to_portable_dig_med_must_use_cryptographic_mechs_to_prot_and_rstrct_ac::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `dbs_employed_to_write_data_to_portable_dig_med_must_use_cryptographic_mechs_to_prot_and_rstrct_ac` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61753
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::dbs_employed_to_write_data_to_portable_dig_med_must_use_cryptographic_mechs_to_prot_and_rstrct_ac {
  ora_secured_setup { "dbs_employed_to_write_data_to_portable_dig_med_must_use_cryptographic_mechs_to_prot_and_rstrct_ac on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
