#
# ora_secured::controls::default_demonstration_and_sample_databases_database_objects_and_applications_must_be_removed
#
# @summary If Oracle is hosted on a server that does not support production systems, and is designated for the deployment of samples and demonstrations, this is not applicable (NA).
# Review documentation and websites from Oracle and any other relevant vendors for vendor-provided demonstration or sample databases, database applications, schemas, objects, and files.
# 
# Review the Oracle DBMS to determine if any of the demonstration and sample databases, schemas, database applications, or files are installed in the database or are included with the DBMS application. If any are present in the database or are included with the DBMS application, this is a finding.
# 
# The Oracle Default Sample Schema User Accounts are:
# 
# BI
# Owns the Business Intelligence schema included in the Oracle Sample Schemas.
# 
# HR
# Manages the Human Resources schema. Schema stores information about the employees and the facilities of the company.
# 
# OE
# Manages the Order Entry schema. Schema stores product inventories and sales of the company's products through various channels.
# 
# PM
# Manages the Product Media schema. Schema contains descriptions and detailed information about each product sold by the company.
# 
# IX
# Manages the Information Exchange schema. Schema manages shipping through business-to-business (B2B) applications database.
# 
# SH
# Manages the Sales schema. Schema stores statistics to facilitate business decisions.
# 
# SCOTT
# A demonstration account with a simple schema.
# 
# Connect to Oracle as SYSDBA; run the following SQL to check for presence of Oracle Default Sample Schema User Accounts:
# select distinct(username) from dba_users where username in
# ('BI','HR','OE','PM','IX','SH','SCOTT');
# 
# If any of the users listed above is returned it means that there are demo programs installed, so this is a finding.
# 
# 
# Remove any demonstration and sample databases, database applications, objects, and files from the DBMS.
# 
# To remove an account and all objects owned by that account (using BI as an example):
# DROP USER BI CASCADE;
# 
# To remove objects without removing their owner, use the appropriate DROP statement (DROP TABLE, DROP VIEW, etc.).
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::default_demonstration_and_sample_databases_database_objects_and_applications_must_be_removed: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::default_demonstration_and_sample_databases_database_objects_and_applications_must_be_removed::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `default_demonstration_and_sample_databases_database_objects_and_applications_must_be_removed` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61677
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::default_demonstration_and_sample_databases_database_objects_and_applications_must_be_removed {
  ora_secured_setup { "default_demonstration_and_sample_databases_database_objects_and_applications_must_be_removed on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
