#
# ora_secured::controls::employ_autom_mechs_to_alert_sec_personnel_of_inappr_or_unusual_act_with_sec_implications
#
# @summary Check DBMS settings to determine whether security personnel are alerted automatically when unusual or security-related activities (threats identified by authoritative sources (e.
# g., CTOs) and IAW with CJCSM 6510.01A) are detected on the database. 
# 
# If security personnel are not automatically alerted, this is a finding.
# 
# Configure database to automatically alert security personnel of inappropriate or unusual activities with security implications.
# 
# Oracle provides this capability with the Audit Vault.  Install and configure Oracle Audit Vault if it is available.
# 
# If Audit Vault is not available, implement custom code or deploy a third-party product to satisfy this requirement.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::employ_autom_mechs_to_alert_sec_personnel_of_inappr_or_unusual_act_with_sec_implications: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::employ_autom_mechs_to_alert_sec_personnel_of_inappr_or_unusual_act_with_sec_implications::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `employ_autom_mechs_to_alert_sec_personnel_of_inappr_or_unusual_act_with_sec_implications` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61779
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::employ_autom_mechs_to_alert_sec_personnel_of_inappr_or_unusual_act_with_sec_implications {
  ora_secured_setup { "employ_autom_mechs_to_alert_sec_personnel_of_inappr_or_unusual_act_with_sec_implications on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
