#
# ora_secured::controls::employ_cryptographic_mechs_preventing_unauth_disclosure_of_info_during_transmission_unless_transm
#
# @summary Check DBMS settings to determine whether cryptographic mechanisms are used to prevent the unauthorized disclosure of information during transmission.
# Determine whether physical measures are being used instead of cryptographic mechanisms. If neither cryptographic nor physical measures are being utilized, this is a finding.
# 
# To check that network encryption is enabled and using site-specified encryption procedures, look in SQLNET.ORA located at $ORACLE_HOME/network/admin/sqlnet.ora. (Note: This assumes that a single sqlnet.ora file, in the default location, is in use. Please see the supplemental file "Non-default sqlnet.ora configurations.pdf" for how to find multiple and/or differently located sqlnet.ora files.) If encryption is set, entries like the following will be present:
# 
# SQLNET.CRYPTO_CHECKSUM_TYPES_CLIENT= (SHA384)
# SQLNET.CRYPTO_CHECKSUM_TYPES_SERVER= (SHA384)
# SQLNET.ENCRYPTION_TYPES_CLIENT= (AES256)
# 
# SQLNET.ENCRYPTION_TYPES_SERVER= (AES256)
# SQLNET.CRYPTO_CHECKSUM_CLIENT = requested
# SQLNET.CRYPTO_CHECKSUM_SERVER = required
# 
# (The values assigned to the parameters may be different, the combination of parameters may be different, and not all of the example parameters will necessarily exist in the file.)
# 
# Configure DBMS and/or operating system to use cryptographic mechanisms to prevent unauthorized disclosure of information during transmission where physical measures are not being utilized.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::employ_cryptographic_mechs_preventing_unauth_disclosure_of_info_during_transmission_unless_transm: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::employ_cryptographic_mechs_preventing_unauth_disclosure_of_info_during_transmission_unless_transm::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `employ_cryptographic_mechs_preventing_unauth_disclosure_of_info_during_transmission_unless_transm` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61545
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::employ_cryptographic_mechs_preventing_unauth_disclosure_of_info_during_transmission_unless_transm {
  ora_secured_setup { "employ_cryptographic_mechs_preventing_unauth_disclosure_of_info_during_transmission_unless_transm on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
