#
# ora_secured::controls::employ_cryptographic_mechs_to_prot_int_and_conf_of_nonlocal_maint_and_diag_comms
#
# @summary Review DBMS configuration to determine if cryptographic mechanisms are being utilized to protect the integrity and confidentiality of nonlocal maintenance and diagnostic communications.
# If not, this is a finding.
# 
# Configure DBMS to utilize cryptographic mechanisms to protect the integrity and confidentiality of nonlocal maintenance and diagnostic communications.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::employ_cryptographic_mechs_to_prot_int_and_conf_of_nonlocal_maint_and_diag_comms: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::employ_cryptographic_mechs_to_prot_int_and_conf_of_nonlocal_maint_and_diag_comms::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `employ_cryptographic_mechs_to_prot_int_and_conf_of_nonlocal_maint_and_diag_comms` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61749
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::employ_cryptographic_mechs_to_prot_int_and_conf_of_nonlocal_maint_and_diag_comms {
  ora_secured_setup { "employ_cryptographic_mechs_to_prot_int_and_conf_of_nonlocal_maint_and_diag_comms on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
