#
# ora_secured::controls::enforce_dac_policy_allowing_users_to_specify_and_control_sharing_by_named_indivs_groups_of_indivs
#
# @summary Check DBMS settings to determine if users are able to assign and revoke rights to the objects and information that they own.
# If users cannot assign or revoke rights to the objects and information that they own to groups, roles, or individual users, this is a finding.
# 
# Modify DBMS settings to allow users to assign or revoke access rights to objects and information owned by the user. The ability to grant or revoke rights must include the ability to grant or revoke those rights down to the granularity of a single user.
# 
# (Note:  In most cases, no fix will be necessary.  This is default functionality for Oracle.)
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::enforce_dac_policy_allowing_users_to_specify_and_control_sharing_by_named_indivs_groups_of_indivs: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::enforce_dac_policy_allowing_users_to_specify_and_control_sharing_by_named_indivs_groups_of_indivs::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `enforce_dac_policy_allowing_users_to_specify_and_control_sharing_by_named_indivs_groups_of_indivs` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61577
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::enforce_dac_policy_allowing_users_to_specify_and_control_sharing_by_named_indivs_groups_of_indivs {
  ora_secured_setup { "enforce_dac_policy_allowing_users_to_specify_and_control_sharing_by_named_indivs_groups_of_indivs on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
