#
# ora_secured::controls::enforce_requirements_for_remote_connections_to_the_information_system
#
# @summary Review organization's access control policies and procedures addressing remote access to the information system.
# Review the DBMS, OS, and/or enterprise account management settings to verify access controls and auditing settings exist and they enforce the requirements for remote access defined by the organization.
# 
# If access controls and auditing do not exist or do not fully enforce the requirements defined in the organization's policies and procedures, this is a finding.
# 
# 
# Configure DBMS settings to ensure access control and auditing requirements for remote connections are enforced by the DBMS.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::enforce_requirements_for_remote_connections_to_the_information_system: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::enforce_requirements_for_remote_connections_to_the_information_system::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `enforce_requirements_for_remote_connections_to_the_information_system` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61675
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::enforce_requirements_for_remote_connections_to_the_information_system {
  ora_secured_setup { "enforce_requirements_for_remote_connections_to_the_information_system on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
