#
# ora_secured::controls::ensure_rmt_sess_that_acc_an_org_def_lst_of_sec_funcs_and_sec_rel_info_are_audited
#
# @summary Verify, using vendor and system documentation if necessary, that the DBMS is configured to use Oracle's auditing features, or that a third-party product or custom code is deployed and configured to satisfy this requirement.
# If a third-party product or custom code is used, compare its current configuration with the audit requirements. If any of the requirements is not covered by the configuration, this is a finding.
# 
# The remainder of this Check is applicable specifically where Oracle auditing is in use.
# 
# If Standard Auditing is used:
# To see if Oracle is configured to capture audit data, enter the following SQL*Plus command:
# SHOW PARAMETER AUDIT_TRAIL
# or the following SQL query:
# SELECT * FROM SYS.V$PARAMETER WHERE NAME = 'audit_trail';
# If Oracle returns the value 'NONE', this is a finding.
# 
# To confirm that Oracle audit is capturing information on the required events, review the contents of the SYS.AUD$ table or the audit file, whichever is in use. If auditable events are not listed, this is a finding.
# 
# If Unified Auditing is used:
# To see if Oracle is configured to capture audit data, enter the following SQL*Plus command:
# SELECT * FROM V$OPTION WHERE PARAMETER = 'Unified Auditing';
# If Oracle returns the value 'TRUE', this is not a finding.
# 
# To confirm that Oracle audit is capturing information on the required events, review the contents of the SYS.UNIFIED_AUDIT_TRAIL view. If auditable events are not listed, this is a finding.
# 
# Configure the DBMS's auditing to audit organization-defined auditable events. If preferred, use a third-party tool. The tool must provide the minimum capability to audit the required events.
# 
# If using a third-party product, proceed in accordance with the product documentation. If using Oracle's capabilities, proceed as follows.
# 
# If Standard Auditing is used:
# Use this process to ensure auditable events are captured:
# ALTER SYSTEM SET AUDIT_TRAIL=<audit trail type> SCOPE=SPFILE;
# Audit trail type can be 'OS', 'DB', 'DB,EXTENDED', 'XML' or 'XML,EXTENDED'.
# After executing this statement, it may be necessary to shut down and restart the Oracle database.
# 
# If the site-specific audit requirements are not covered by the default audit options, deploy and configure Fine-Grained Auditing.  For details, refer to Oracle documentation at the locations below.
# 
# If Unified Auditing is used:
# Use this process to ensure auditable events are captured:
# Link the oracle binary with uniaud_on, and then restart the database. Oracle Database Upgrade Guide describes how to enable unified auditing.
# 
# For more information on the configuration of auditing, refer to the following documents:
# "Auditing Database Activity" in the Oracle Database 2 Day + Security Guide:
# http://docs.oracle.com/database/121/TDPSG/tdpsg_auditing.htm#TDPSG50000
# "Monitoring Database Activity with Auditing" in the Oracle Database Security Guide:
# http://docs.oracle.com/database/121/DBSEG/part_6.htm#CCHEHCGI
# "DBMS_AUDIT_MGMT" in the Oracle Database PL/SQL Packages and Types Reference:
# http://docs.oracle.com/database/121/ARPLS/d_audit_mgmt.htm#ARPLS241
# Oracle Database Upgrade Guide:
# http://docs.oracle.com/database/121/UPGRD/afterup.htm#UPGRD52810
# 
# If the site-specific audit requirements are not covered by the default audit options, deploy and configure Fine-Grained Auditing.  For details, refer to Oracle documentation at the locations above.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::ensure_rmt_sess_that_acc_an_org_def_lst_of_sec_funcs_and_sec_rel_info_are_audited: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::ensure_rmt_sess_that_acc_an_org_def_lst_of_sec_funcs_and_sec_rel_info_are_audited::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `ensure_rmt_sess_that_acc_an_org_def_lst_of_sec_funcs_and_sec_rel_info_are_audited` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61553
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::ensure_rmt_sess_that_acc_an_org_def_lst_of_sec_funcs_and_sec_rel_info_are_audited {
  ora_secured_setup { "ensure_rmt_sess_that_acc_an_org_def_lst_of_sec_funcs_and_sec_rel_info_are_audited on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
