#
# ora_secured::controls::ensure_users_are_auth_with_an_indiv_authenticator_prior_to_using_a_shared_authenticator
#
# @summary Review DBMS settings, OS settings, and/or enterprise-level authentication/access mechanism settings to determine whether shared accounts exist.
# If group accounts do not exist, this is NA.
# 
# Review DBMS settings to determine if individual authentication is required before shared authentication.
# 
# If shared authentication does not require prior individual authentication, this is a finding.
# 
# (Oracle Access Manager may be helpful in meeting this requirement. Notes on Oracle Access Manager follow.)
# 
# Oracle Access Manager is used when there is a need for multifactor authentication of applications front-ending Oracle Datasets that may use group accounts. Oracle Access Manager supports using PKI-based smart cards (CAC, PIV) for multifactor authentication. When a user authenticates to a smart card application, the smart card engine produces a certificate-based authentication token. Can configure a certificate-based authentication scheme in Oracle Access Manager that uses information from the smart card certificate. Certificate-based authentication works with any smart card or similar device that presents an X.509 certificate.
# 
# Check:
# First, check that the Authentication Module is set up properly:
# 1) Go to Oracle Access Manager Home Screen and click the Policy Configuration tab.  Select the X509Scheme.
# 2) Make sure the Authentication Module option is set to X509Plugin.
# 
# Second, check that the Authentication policy is using the x509Scheme:
# 1) Go to Oracle Access Manager Home Screen and click the Policy Configuration tab.
# 2) Select Application Domains.  Select Search.
# 3) Select the application domain protecting the Oracle Database.
# 4) Select the Authentication Polices tab and Click Protected Resource Policy.
# 5) Make sure the Authentication Scheme is set to x509Scheme.
# 
# Configure DBMS, OS and/or enterprise-level authentication/access mechanism to require individual authentication prior to authentication for shared account access.
# 
# If appropriate, install Oracle Access Manager to provide multifactor authentication of applications front-ending Oracle Databases and using shared accounts.  After installation, use x509 Authentication modules provided out of the box.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::ensure_users_are_auth_with_an_indiv_authenticator_prior_to_using_a_shared_authenticator: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::ensure_users_are_auth_with_an_indiv_authenticator_prior_to_using_a_shared_authenticator::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `ensure_users_are_auth_with_an_indiv_authenticator_prior_to_using_a_shared_authenticator` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61711
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::ensure_users_are_auth_with_an_indiv_authenticator_prior_to_using_a_shared_authenticator {
  ora_secured_setup { "ensure_users_are_auth_with_an_indiv_authenticator_prior_to_using_a_shared_authenticator on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
