#
# ora_secured::controls::execute_is_revoked_from_public_on_dbms_credential_package
#
# @summary As described below, Oracle Database PL/SQL "DBMS_CREDENTIAL" package – should not be granted to PUBLIC.
# - Use of the DBMS_CREDENTIAL package could allow an unauthorized user to add, create, drop, enable and update credentials allowing jobs to run on the operating system.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 5.1.1.7
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::execute_is_revoked_from_public_on_dbms_credential_package: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::execute_is_revoked_from_public_on_dbms_credential_package::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `execute_is_revoked_from_public_on_dbms_credential_package` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param list
#    This is an internal list of objects to apply the control to.
#    Don't modify
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::execute_is_revoked_from_public_on_dbms_credential_package () {
  $sid = $title
  ora_secured_setup { "execute_is_revoked_from_public_on_dbms_credential_package on ${title}":
    ensure => 'present',
  }

  -> ora_secured::internal::revoke_public_grants { "DBMS_CREDENTIAL@${sid}": }
}
