#
# ora_secured::controls::extproc_is_not_present_in_listener_ora
#
# @summary `extproc` should be removed from the `listener.
# ora` to mitigate the risk that OS
# libraries can be invoked by the Oracle instance.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 2.1.2
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 2.1.2
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 2.1.1
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 2.1.1
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::extproc_is_not_present_in_listener_ora: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::extproc_is_not_present_in_listener_ora::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `extproc_is_not_present_in_listener_ora` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::extproc_is_not_present_in_listener_ora () {
  alert('Specified CIS rule is not yet automatically enforced.')
}
