#
# ora_secured::controls::identify_potentially_security_relevant_error_conditions
#
# @summary Check DBMS settings to determine whether security-related error conditions are monitored for, and whether appropriate personnel are notified.
# If security-related error conditions are not being monitored for, this is a finding.
# 
# If appropriate personnel are not alerted when a security-related error condition is found, this is a finding.
# 
# Configure DBMS to monitor for security-related error conditions.
# 
# Configure DBMS to alert appropriate personnel when security-related error conditions are found.
# 
# This can be accomplished by using Oracle Audit Vault and/or Oracle Enterprise Manager. If neither of these products is deployed, then develop a site-specific solution.
# 
# - - - - -
# Notes to assist in developing a site-specific solution:
# 
# The AUD$ table has a column called RETURNCODE.  That column provides the return code; so, for example, if the security-related condition is someone trying to select data from a table that is not there, it would show up in the AUD$ table as an ORA-00942 - table or view does not exist.  Since the RETURNCODE column is only numeric, only the 00942 would be stored. If the query for the information returned a row, the process would then need to form and send an email message.
# 
# Oracle recommends the use of Oracle Audit Vault to fill this requirement without creating a custom solution.   It is possible to set up notifications and alerts in Enterprise Manager as well, and if either of these alternatives is not available, a custom solution will be necessary.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::identify_potentially_security_relevant_error_conditions: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::identify_potentially_security_relevant_error_conditions::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `identify_potentially_security_relevant_error_conditions` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61789
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::identify_potentially_security_relevant_error_conditions {
  ora_secured_setup { "identify_potentially_security_relevant_error_conditions on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
