#
# ora_secured::controls::issm_must_review_changes_to_dba_role_assignments
#
# @summary Review policy and procedures documented or noted in the System Security Plan as well as evidence of implementation for monitoring changes to DBA role assignments and procedures for notifying the ISSM of the changes for review.
# If policy, procedures or implementation evidence do not exist, this is a finding.
# 
# Develop, document and implement procedures to monitor changes to DBA role assignments.
# 
# Develop, document and implement procedures to notify the ISSM of changes to DBA role assignments.
# 
# Include in the procedures methods that provide evidence of monitoring and notification.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::issm_must_review_changes_to_dba_role_assignments: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::issm_must_review_changes_to_dba_role_assignments::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `issm_must_review_changes_to_dba_role_assignments` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61497
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::issm_must_review_changes_to_dba_role_assignments {
  ora_secured_setup { "issm_must_review_changes_to_dba_role_assignments on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
