#
# ora_secured::controls::logic_modules_within_db_to_incl_pkgs_procs_funcs_and_trggrs_must_be_mon_to_disc_unauth_changes
#
# @summary Review monitoring procedures and implementation evidence to verify that monitoring of changes to database logic modules is done.
# Verify the list of objects (packages, procedures, functions, and triggers) being monitored is complete. If monitoring does not occur or is not complete, this is a finding.
# 
# Implement procedures to monitor for unauthorized changes to database logic modules. If a third-party automated tool is not employed, an automated job that reports on the objects of interest and compares them to the baseline report for the same will meet the requirement.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::logic_modules_within_db_to_incl_pkgs_procs_funcs_and_trggrs_must_be_mon_to_disc_unauth_changes: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::logic_modules_within_db_to_incl_pkgs_procs_funcs_and_trggrs_must_be_mon_to_disc_unauth_changes::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `logic_modules_within_db_to_incl_pkgs_procs_funcs_and_trggrs_must_be_mon_to_disc_unauth_changes` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-68863
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::logic_modules_within_db_to_incl_pkgs_procs_funcs_and_trggrs_must_be_mon_to_disc_unauth_changes {
  ora_secured_setup { "logic_modules_within_db_to_incl_pkgs_procs_funcs_and_trggrs_must_be_mon_to_disc_unauth_changes on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
