#
# ora_secured::controls::minimum_of_two_orcl_redo_log_groups_files_must_be_def_and_configed_to_be_strd_on_separate_archive
#
# @summary From SQL*Plus:
# select count(*) from V$LOG;
# 
# If the value of the count returned is less than 2, this is a finding.
# 
# 
#   select count(*) from V$LOG where members > 1;
# 
# If the value of the count returned is less than 2 and a RAID storage device is not being used, this is a finding.
# 
# To define additional redo log file groups:
# 
# From SQL*Plus (Example):
# 
#   alter database add logfile group 2 
#     ('diska:log2.log' ,
#      'diskb:log2.log') size 50K; 
# 
# To add additional redo log file [members] to an existing redo log file group:
# 
# From SQL*Plus (Example):
# 
#   alter database add logfile member 'diskc:log2.log'
#   to group 2;
# 
# Replace diska, diskb, diskc with valid, different disk drive specifications.
# 
# Replace log#.log file with valid or custom names for the log files.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::minimum_of_two_orcl_redo_log_groups_files_must_be_def_and_configed_to_be_strd_on_separate_archive: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::minimum_of_two_orcl_redo_log_groups_files_must_be_def_and_configed_to_be_strd_on_separate_archive::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `minimum_of_two_orcl_redo_log_groups_files_must_be_def_and_configed_to_be_strd_on_separate_archive` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61419
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::minimum_of_two_orcl_redo_log_groups_files_must_be_def_and_configed_to_be_strd_on_separate_archive {
  ora_secured_setup { "minimum_of_two_orcl_redo_log_groups_files_must_be_def_and_configed_to_be_strd_on_separate_archive on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
