#
# ora_secured::controls::not_share_a_host_supporting_an_independent_security_service
#
# @summary Review the services and processes active on the DBMS host system.
# If the host system is a Windows domain controller, this is a finding.
# 
# If the host system is supporting any other security or directory services that do not use the DBMS to store information, this is a finding.
# 
# Note: This does not include client security applications like firewall and antivirus software.
# 
# Either move the DBMS installation to a dedicated host system or move the directory or security services to another host system.
# 
# A dedicated host system in this case refers to an instance of the operating system at a minimum.
# 
# The operating system may reside on a virtual host machine where supported by the DBMS vendor.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::not_share_a_host_supporting_an_independent_security_service: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::not_share_a_host_supporting_an_independent_security_service::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `not_share_a_host_supporting_an_independent_security_service` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61509
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::not_share_a_host_supporting_an_independent_security_service {
  ora_secured_setup { "not_share_a_host_supporting_an_independent_security_service on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
