#
# ora_secured::controls::only_auth_sys_accnts_must_have_sys_tablespace_specified_as_default_tablespace
#
# @summary Run the query:
# select property_name, property_value
# from database_properties
# where property_name in 
# ('DEFAULT_PERMANENT_TABLESPACE','DEFAULT_TEMP_TABLESPACE');
# 
# If either value is set to SYSTEM, this is a finding.
# 
# Run the query:
# 
# select username from dba_users 
# where (default_tablespace = 'SYSTEM' or temporary_tablespace = 'SYSTEM')
# and username not in
# ('LBACSYS','OUTLN','SYS','SYSTEM', 'SYSKM', 'SYSDG', 'SYSBACKUP');
# 
# If any non-default account records are returned, this is a finding.
# 
# 
# Create and dedicate tablespaces to support only one application.
# 
# Do not share tablespaces between applications.
# 
# Do not grant quotas to application object owners on tablespaces not dedicated to their associated application.
# 
# Run the queries:
# 
# alter database default tablespace <tablespace_name>;
# alter database default temporary tablespace <temporary_tablespace_name>;
# 
# alter user <username> default tablespace <tablespace_name> temporary tablespace <temporary_tablespace_name>;
# 
# Replace <username> with the named user account.
# Replace <tablespace_name> with the new default tablespace name.
# Replace <temporary_tablespace_name> with the new default temporary tablespace name (typically TEMP).
# Repeat the "alter user" for each affected user account.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::only_auth_sys_accnts_must_have_sys_tablespace_specified_as_default_tablespace: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::only_auth_sys_accnts_must_have_sys_tablespace_specified_as_default_tablespace::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `only_auth_sys_accnts_must_have_sys_tablespace_specified_as_default_tablespace` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61459
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::only_auth_sys_accnts_must_have_sys_tablespace_specified_as_default_tablespace {
  ora_secured_setup { "only_auth_sys_accnts_must_have_sys_tablespace_specified_as_default_tablespace on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
