#
# ora_secured::controls::only_gen_error_messages_that_prov_info_necessary_for_corrective_actions_without_revealing_org_def
#
# @summary Check DBMS settings and custom database and application code to verify error messages do not contain information beyond what is needed for troubleshooting the issue.
# If database errors contain PII data, sensitive business data, or information useful for identifying the host system, this is a finding.
# 
# Notes on Oracle's approach to this issue:  Out of the box, Oracle covers this. For example, if a user does not have access to a table, the error is just that the table or view does not exist. The Oracle database is not going to display a Social Security Number in an error code unless an application is programmed to do so.  Oracle applications will not expose the actual transactional data to a screen.  The only way Oracle will capture this information is to enable specific logging levels.  Custom code would require a review to ensure compliance.
# 
# Configure DBMS and custom database and application code not to divulge sensitive information or information useful for system identification in error information.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::only_gen_error_messages_that_prov_info_necessary_for_corrective_actions_without_revealing_org_def: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::only_gen_error_messages_that_prov_info_necessary_for_corrective_actions_without_revealing_org_def::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `only_gen_error_messages_that_prov_info_necessary_for_corrective_actions_without_revealing_org_def` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61791
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::only_gen_error_messages_that_prov_info_necessary_for_corrective_actions_without_revealing_org_def {
  ora_secured_setup { "only_gen_error_messages_that_prov_info_necessary_for_corrective_actions_without_revealing_org_def on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
