#
# ora_secured::controls::oracle_instance_names_must_not_contain_oracle_version_numbers
#
# @summary From SQL*Plus:
# select instance_name from v$instance;
#   select version from v$instance;
# 
# If the instance name returned references the Oracle release number, this is a finding.
# 
# Numbers used that include version numbers by coincidence are not a finding.
# 
# The DBA should be able to relate the significance of the presence of a digit in the SID.
# 
# Follow the instructions in Oracle MetaLink Note 15390.1 (and related documents) to change the SID for the database without re-creating the database to a value that does not identify the Oracle version.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::oracle_instance_names_must_not_contain_oracle_version_numbers: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::oracle_instance_names_must_not_contain_oracle_version_numbers::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `oracle_instance_names_must_not_contain_oracle_version_numbers` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61413
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::oracle_instance_names_must_not_contain_oracle_version_numbers {
  ora_secured_setup { "oracle_instance_names_must_not_contain_oracle_version_numbers on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
