#
# ora_secured::controls::oracle_must_back_up_user_level_information_per_a_defined_frequency
#
# @summary Review DBMS settings and site documentation to determine whether Oracle is configured to back up user-level data according to a defined frequency.
# If it is not, this is a finding.
# 
# (The V$RMAN_STATUS view displays the finished and on-going RMAN jobs. For on-going jobs, this view displays progress and status.)
# 
# Configure the Oracle DBMS to back up user-level data on a defined frequency.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::oracle_must_back_up_user_level_information_per_a_defined_frequency: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::oracle_must_back_up_user_level_information_per_a_defined_frequency::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `oracle_must_back_up_user_level_information_per_a_defined_frequency` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61693
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::oracle_must_back_up_user_level_information_per_a_defined_frequency {
  ora_secured_setup { "oracle_must_back_up_user_level_information_per_a_defined_frequency on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
