#
# ora_secured::controls::oracle_roles_granted_using_the_with_admin_option_must_not_be_granted_to_unauthorized_accounts
#
# @summary A default Oracle Database installation provides a set of predefined administrative accounts and non-administrative accounts.
# These are accounts that have special privileges required to administer areas of the database, such as the CREATE ANY TABLE or ALTER SESSION privilege, or EXECUTE privileges on packages owned by the SYS schema. The default tablespace for administrative accounts is either SYSTEM or SYSAUX. Non-administrative user accounts only have the minimum privileges needed to perform their jobs. Their default tablespace is USERS.
# 
# To protect these accounts from unauthorized access, the installation process expires and locks most of these accounts, except where noted below. The database administrator is responsible for unlocking and resetting these accounts, as required.
# 
# Non-Administrative Accounts - Expired and locked:
# APEX_PUBLIC_USER, DIP, FLOWS_040100*, FLOWS_FILES, MDDATA, ORACLE_OCM, SPATIAL_CSW_ADMIN_USR, SPATIAL_WFS_ADMIN_USR, XS$NULL
# 
# Administrative Accounts - Expired and Locked:
# ANONYMOUS, CTXSYS, EXFSYS, LBACSYS, MDSYS, OLAPSYS, ORDDATA, OWBSYS, ORDPLUGINS, ORDSYS, OUTLN, SI_INFORMTN_SCHEMA, WK_TEST, WK_SYS, WKPROXY, WMSYS, XDB
# 
# Administrative Accounts - Open:
# DBSNMP, MGMT_VIEW, SYS, SYSMAN, SYSTEM
# 
# * Subject to change based on version installed
# 
# Run the SQL statement:
# 
#   select grantee||': '||granted_role from dba_role_privs
#   where grantee not in
#   (<list of non-applicable accounts>)
#   and admin_option = 'YES' 
#   and grantee not in
#   (select distinct owner from dba_objects)
#   and grantee not in
#   (select grantee from dba_role_privs
#    where granted_role = 'DBA')
#   order by grantee;
# 
# (With respect to the list of special accounts that are excluded from this requirement, it is expected that the DBA will maintain the list to suit local circumstances, adding special accounts as necessary and removing any that are not supposed to be in use in the Oracle deployment that is under review.)
# 
# Review the System Security Plan to confirm any grantees listed are ISSO-authorized DBA accounts or application administration roles.
# 
# If any grantees listed are not authorized and documented, this is a finding.
# 
# Revoke assignment of roles with the WITH ADMIN OPTION from unauthorized grantees and re-grant them without the option if required.
# 
# SQL statements to remove the admin option from an unauthorized grantee:
#   revoke <role name> from <grantee>;
#   grant <role name> to <grantee>;
# 
# Restrict use of the WITH ADMIN OPTION to authorized administrators.
# 
# Document authorized role assignments with the WITH ADMIN OPTION in the System Security Plan.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::oracle_roles_granted_using_the_with_admin_option_must_not_be_granted_to_unauthorized_accounts: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::oracle_roles_granted_using_the_with_admin_option_must_not_be_granted_to_unauthorized_accounts::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `oracle_roles_granted_using_the_with_admin_option_must_not_be_granted_to_unauthorized_accounts` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61437
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::oracle_roles_granted_using_the_with_admin_option_must_not_be_granted_to_unauthorized_accounts {
  ora_secured_setup { "oracle_roles_granted_using_the_with_admin_option_must_not_be_granted_to_unauthorized_accounts on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
