#
# ora_secured::controls::oracle_trace_files_public_parameter_if_present_must_be_set_to_false
#
# @summary From SQL*Plus:
# select value from v$parameter where name = '_trace_files_public';
# 
# If the value returned is TRUE, this is a finding.
# 
# If the parameter does not exist or is set to FALSE, this is not a finding.
# 
# From SQL*Plus (shutdown database instance):
# 
#   shutdown immediate
# 
# From SQL*Plus (create a pfile from spfile):
# 
#   create pfile='[PATH]init[SID].ora' from spfile;
# 
# Edit the init[SID].ora file and remove the following line:
# 
#   *._trace_files_public=TRUE
# 
# From SQL*Plus (update the spfile using the pfile):
# 
#   create spfile from pfile='[PATH]init[SID].ora';
# 
# From SQL*Plus (start the database instance):
# 
#   startup
# 
# Note: [PATH] depends on the platform (Windows or UNIX).
# 
# Ensure the file is directed to a writable location.
# 
# [SID] is equal to the oracle SID or database instance ID.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::oracle_trace_files_public_parameter_if_present_must_be_set_to_false: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::oracle_trace_files_public_parameter_if_present_must_be_set_to_false::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `oracle_trace_files_public_parameter_if_present_must_be_set_to_false` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61465
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::oracle_trace_files_public_parameter_if_present_must_be_set_to_false {
  ora_secured_setup { "oracle_trace_files_public_parameter_if_present_must_be_set_to_false on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
