#
# ora_secured::controls::orcl_with_grnt_option_priv_must_not_be_grnted_to_non_dba_or_non_app_admin_user_accnts
#
# @summary Execute the query:
# select grantee||': '||owner||'.'||table_name
# from dba_tab_privs 
# where grantable = 'YES' 
# and grantee not in (select distinct owner from dba_objects)
# and grantee not in (select grantee from dba_role_privs where granted_role = 'DBA')
# and table_name not like 'SYS_PLSQL_%'
# order by grantee;
# 
# 
# If any accounts are listed, this is a finding.
# 
# Revoke privileges granted the WITH GRANT OPTION from non-DBA and accounts that do not own application objects.
# 
# Re-grant privileges without specifying WITH GRANT OPTION.
# 
# Note: Do not revoke the system-generated grants such as those found on The SYS_PLSQL_% objects. They are system generated object types (a.k.a ShadowTypes) which are created internally by Oracle when you use the Pipelined Table Functions. This can result in (incorrect) compilation failures and/or invalidations when the users who are supposed to have access to the shadow types find themselves without access.
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::orcl_with_grnt_option_priv_must_not_be_grnted_to_non_dba_or_non_app_admin_user_accnts: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::orcl_with_grnt_option_priv_must_not_be_grnted_to_non_dba_or_non_app_admin_user_accnts::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `orcl_with_grnt_option_priv_must_not_be_grnted_to_non_dba_or_non_app_admin_user_accnts` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61421
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::orcl_with_grnt_option_priv_must_not_be_grnted_to_non_dba_or_non_app_admin_user_accnts {
  ora_secured_setup { "orcl_with_grnt_option_priv_must_not_be_grnted_to_non_dba_or_non_app_admin_user_accnts on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
