#
# ora_secured::controls::os_accounts_utilized_to_run_external_procedures_called_by_the_dbms_must_have_limited_privileges
#
# @summary Determine which OS accounts are used by the DBMS to run external procedures.
# Validate that these OS accounts have only the privileges necessary to perform the required functionality.
# 
# If any OS accounts, utilized by the database for running external procedures, have privileges beyond those required for running the external procedures, this is a finding.
# 
# If use of the external procedure agent is authorized, ensure extproc is restricted to execution of authorized applications.
# 
# External jobs are run using the account nobody by default.
# 
# Review the contents of the file ORACLE_HOME/rdbms/admin/externaljob.ora for the lines run_user= and run_group=.
# 
# If the user assigned to these parameters is not "nobody", this is a finding.
# 
# System views providing privilege information are:
# DBA_SYS_PRIVS
# DBA_TAB_PRIVS
# DBA_ROLE_PRIVS
# 
# Limit privileges to DBMS-related OS accounts to those required to perform their DBMS specific functionality.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::os_accounts_utilized_to_run_external_procedures_called_by_the_dbms_must_have_limited_privileges: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::os_accounts_utilized_to_run_external_procedures_called_by_the_dbms_must_have_limited_privileges::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `os_accounts_utilized_to_run_external_procedures_called_by_the_dbms_must_have_limited_privileges` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61601
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::os_accounts_utilized_to_run_external_procedures_called_by_the_dbms_must_have_limited_privileges {
  ora_secured_setup { "os_accounts_utilized_to_run_external_procedures_called_by_the_dbms_must_have_limited_privileges on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
