#
# ora_secured::controls::os_must_lmt_privs_to_change_dbms_sw_resident_within_sw_libs_including_privd_programs
#
# @summary Review permissions that control access to the DBMS software libraries.
# The software library location may be determined from vendor documentation or service/process executable paths.
# 
# DBA accounts, the DBMS process account, the DBMS software installation/maintenance account, SA accounts, if access by them is required for some operational level of support such as backups, and the host system itself require access. Any others should be scrutinized and a reason for access provided by the DBA.
# 
# If accounts that are not required and authorized to have access to the software library location do have access, this is a finding.
# 
# Check to see which users have been granted DBA.  Work from a basis of least privilege.  Provide the least amount of privilege required to accomplish the job.
# 
# SQL> select * from dba_role_privs where granted_role = 'DBA';
# 
# Restrict access to the DBMS software libraries to accounts that require access based on job function.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::os_must_lmt_privs_to_change_dbms_sw_resident_within_sw_libs_including_privd_programs: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::os_must_lmt_privs_to_change_dbms_sw_resident_within_sw_libs_including_privd_programs::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `os_must_lmt_privs_to_change_dbms_sw_resident_within_sw_libs_including_privd_programs` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61869
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::os_must_lmt_privs_to_change_dbms_sw_resident_within_sw_libs_including_privd_programs {
  ora_secured_setup { "os_must_lmt_privs_to_change_dbms_sw_resident_within_sw_libs_including_privd_programs on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
