#
# ora_secured::controls::pdb_os_credential_is_not_null
#
# @summary The pdb_os_credential setting determines what OS user will be utilized to run jobs at the OS level from within the Oracle database.
# ## Rationale
# 
# Permitting a job to run at the OS level with default credential, Oracle OS user, can allow for excessive privileges that a job should not have.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 2.2.17
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::pdb_os_credential_is_not_null: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::pdb_os_credential_is_not_null::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `pdb_os_credential_is_not_null` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::pdb_os_credential_is_not_null (
  String  $preferred_value = ora_secured::lookup_setting('preferred_value','oracle'),
) {
  $sid = $title
  $unique = ora_secured::random_id(6)

  ora_secured_setup { "pdb_os_credential_is_not_null on ${title}":
    ensure => 'present',
  }

  -> ora_secured::internal::parameter { "PDB_OS_CREDENTIAL@${sid}@${unique}":
    value => $preferred_value,
  }
}
