#
# ora_secured::controls::plans_and_procs_for_testing_dbms_installations_upgrades_and_patches_must_be_def_and_followed_prio
#
# @summary Review policy and procedures documented or noted in the System Security Plan and evidence of implementation for testing DBMS installations, upgrades and patches prior to production deployment.
# If policy and procedures do not exist or evidence of implementation does not exist, this is a finding.
# 
# Develop, document and implement procedures for testing DBMS installations, upgrades and patches prior to deployment on production systems.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::plans_and_procs_for_testing_dbms_installations_upgrades_and_patches_must_be_def_and_followed_prio: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::plans_and_procs_for_testing_dbms_installations_upgrades_and_patches_must_be_def_and_followed_prio::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `plans_and_procs_for_testing_dbms_installations_upgrades_and_patches_must_be_def_and_followed_prio` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61499
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::plans_and_procs_for_testing_dbms_installations_upgrades_and_patches_must_be_def_and_followed_prio {
  ora_secured_setup { "plans_and_procs_for_testing_dbms_installations_upgrades_and_patches_must_be_def_and_followed_prio on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
