#
# ora_secured::controls::prevent_presentation_of_info_sys_mgmt_related_functionality_at_an_interface_utilized_by_general_i
#
# @summary Check DBMS settings and vendor documentation to verify administrative functionality is separate from user functionality.
# If administrator and general user functionality is not separated either physically or logically, this is a finding.
# 
# Configure DBMS settings to separate database administration and general user functionality.  Provide those who have both administrative and general-user responsibilities with separate accounts for these separate functions.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::prevent_presentation_of_info_sys_mgmt_related_functionality_at_an_interface_utilized_by_general_i: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::prevent_presentation_of_info_sys_mgmt_related_functionality_at_an_interface_utilized_by_general_i::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `prevent_presentation_of_info_sys_mgmt_related_functionality_at_an_interface_utilized_by_general_i` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61885
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::prevent_presentation_of_info_sys_mgmt_related_functionality_at_an_interface_utilized_by_general_i {
  ora_secured_setup { "prevent_presentation_of_info_sys_mgmt_related_functionality_at_an_interface_utilized_by_general_i on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
