#
# ora_secured::controls::prevent_unauthorized_and_unintended_information_transfer_via_shared_system_resources
#
# @summary Verify there are proper procedures in place for the refreshing of development/test data from production.
# Review any scripts or code that exists for the movement of production data to development/test, and verify copies of production data are not left in unprotected locations.
# 
# If there is no documented procedure for data movement from production to development/test, this is a finding.
# 
# If the code that exists for data movement does not remove any copies of production data from unprotected locations, this is a finding.
# 
# Create and document a process for moving data from production to development/test systems, and follow the process.
# 
# Modify any code used for moving data from production to development/test systems to ensure copies of production data are not left in nonsecured locations.
# 
# Moving data is only a part of the challenge of protecting the data.  When the data is moved, it should also be changed so sensitive information is not made available in development environments.
# 
# With the Oracle Data Masking Pack for Oracle Enterprise Manager, organizations can comply with data privacy and protection mandates that restrict the use of actual customer data. With Oracle Data Masking Pack, sensitive information, such as credit card or social security numbers, can be replaced with realistic values, allowing production data to be safely used for development, testing, or sharing with out-source or off-shore partners for other nonproduction purposes.  When used in conjunction with Oracle Enterprise Manager, it is easy to develop a secure process that is capable of obfuscating the data during the movement process.
# 
# If the Oracle Data Masking Pack and Enterprise Manager are not available, develop site-specific procedures to manage and obfuscate sensitive data.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::prevent_unauthorized_and_unintended_information_transfer_via_shared_system_resources: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::prevent_unauthorized_and_unintended_information_transfer_via_shared_system_resources::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `prevent_unauthorized_and_unintended_information_transfer_via_shared_system_resources` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61781
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::prevent_unauthorized_and_unintended_information_transfer_via_shared_system_resources {
  ora_secured_setup { "prevent_unauthorized_and_unintended_information_transfer_via_shared_system_resources on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
