#
# ora_secured::controls::procs_for_esting_tmp_pwds_that_meet_dod_pwd_reqs_for_new_accnts_must_be_def_doc_and_impl
#
# @summary If all user accounts are authenticated by the OS or an enterprise-level authentication/access mechanism, and not by Oracle, this is not a finding.
# Where accounts are authenticated using passwords, review procedures and implementation evidence for creation of temporary passwords.
# 
# If the procedures or evidence do not exist or do not enforce passwords to meet DoD password requirements, this is a finding.
# 
# Implement procedures for assigning temporary passwords to user accounts.
# 
# Procedures should include instructions to meet current DoD password length and complexity requirements and provide a secure method to relay the temporary password to the user.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::procs_for_esting_tmp_pwds_that_meet_dod_pwd_reqs_for_new_accnts_must_be_def_doc_and_impl: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::procs_for_esting_tmp_pwds_that_meet_dod_pwd_reqs_for_new_accnts_must_be_def_doc_and_impl::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `procs_for_esting_tmp_pwds_that_meet_dod_pwd_reqs_for_new_accnts_must_be_def_doc_and_impl` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61735
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::procs_for_esting_tmp_pwds_that_meet_dod_pwd_reqs_for_new_accnts_must_be_def_doc_and_impl {
  ora_secured_setup { "procs_for_esting_tmp_pwds_that_meet_dod_pwd_reqs_for_new_accnts_must_be_def_doc_and_impl on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
