#
# ora_secured::controls::procs_services_apps_etc_that_connect_to_dbms_independently_of_indiv_users_must_use_valid_current
#
# @summary Review configuration to confirm that accounts used by processes to connect to the DBMS are authenticated using valid, current DoD-issued PKI certificates.
# If any such account (other than SYS, SYSBACKUP, SYSDG, and SYSKM) is not certificate-based, this is a finding.
# 
# For each such account, use DoD certificate-based authentication.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::procs_services_apps_etc_that_connect_to_dbms_independently_of_indiv_users_must_use_valid_current: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::procs_services_apps_etc_that_connect_to_dbms_independently_of_indiv_users_must_use_valid_current::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `procs_services_apps_etc_that_connect_to_dbms_independently_of_indiv_users_must_use_valid_current` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61745
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::procs_services_apps_etc_that_connect_to_dbms_independently_of_indiv_users_must_use_valid_current {
  ora_secured_setup { "procs_services_apps_etc_that_connect_to_dbms_independently_of_indiv_users_must_use_valid_current on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
