#
# ora_secured::controls::prot_against_an_indiv_who_uses_a_shared_accnt_falsely_denying_having_perfd_a_particular_action
#
# @summary If there are no shared accounts available to more than one user, this is not a finding.
# If a shared account is used by an application to interact with the database, review the System Security Plan, the tables in the database, and the application source code/documentation to determine whether the application captures the individual user's identity and stores that identity along with all data inserted and updated (also with all records of reads and/or deletions, if these are required to be logged).
# 
# If there are gaps in the application's ability to do this, and the gaps and the risk are not defined in the system documentation and accepted by the AO, this is a finding.
# 
# If users are sharing a group account to log on to Oracle tools or third-party products that access the database, this is a finding.
# 
# If Standard Auditing is used:
# To ensure that user activities other than SELECT, INSERT, UPDATE, and DELETE are also monitored and attributed to individuals, verify that Oracle auditing is enabled. To see if Oracle is configured to capture audit data, enter the following SQL*Plus command:
# SHOW PARAMETER AUDIT_TRAIL
# or the following SQL query:
# SELECT * FROM SYS.V$PARAMETER WHERE NAME = 'audit_trail';
# If Oracle returns the value 'NONE', this is a finding.
# 
# If Unified Auditing is used:
# To ensure that user activities other than SELECT, INSERT, UPDATE, and DELETE are also monitored and attributed to individuals, verify that Oracle auditing is enabled. To see if Oracle is configured to capture audit data, enter the following SQL*Plus command:
# SELECT * FROM V$OPTION WHERE PARAMETER = 'Unified Auditing';
# If Oracle returns the value "TRUE", this is not a finding.
# 
# Use accounts assigned to individual users where feasible. Configure DBMS to provide individual accountability at the DBMS level, and in audit logs, for actions performed under a shared database account.
# 
# Modify applications and data tables that are not capturing individual user identity to do so.
# 
# Create and enforce the use of individual user IDs for logging on to Oracle tools and third-party products.
# 
# If Oracle auditing is not already enabled, enable it.
# 
# If Standard Auditing is used:
# If Oracle (or third-party) auditing is not already enabled, enable it. For Oracle auditing, use this query:
# ALTER SYSTEM SET AUDIT_TRAIL=<audit trail type> SCOPE=SPFILE;
# Audit trail type can be 'OS', 'DB', 'DB,EXTENDED', 'XML' or 'XML,EXTENDED'.
# After executing this statement, it may be necessary to shut down and restart the Oracle database.
# 
# If Unified Auditing is used:
# Link the oracle binary with uniaud_on, and then restart the database. Oracle Database Upgrade Guide describes how to enable unified auditing.
# 
# For more information on the configuration of auditing, refer to the following documents:
# "Auditing Database Activity" in the Oracle Database 2 Day + Security Guide:
# http://docs.oracle.com/database/121/TDPSG/tdpsg_auditing.htm#TDPSG50000
# "Monitoring Database Activity with Auditing" in the Oracle Database Security Guide: 
# http://docs.oracle.com/database/121/DBSEG/part_6.htm#CCHEHCGI
# "DBMS_AUDIT_MGMT" in the Oracle Database PL/SQL Packages and Types Reference:
# http://docs.oracle.com/database/121/ARPLS/d_audit_mgmt.htm#ARPLS241
# Oracle Database Upgrade Guide:
# http://docs.oracle.com/database/121/UPGRD/afterup.htm#UPGRD52810
# 
# If the site-specific audit requirements are not covered by the default audit options, deploy and configure Fine-Grained Auditing.  For details, refer to Oracle documentation at the locations above.
# 
# If this level of auditing does not meet site-specific requirements, consider deploying the Oracle Audit Vault.  The Audit Vault is a highly configurable option from Oracle made specifically for performing the audit functions.  It has reporting capabilities as well as user-defined rules that provide additional flexibility for complex auditing requirements.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::prot_against_an_indiv_who_uses_a_shared_accnt_falsely_denying_having_perfd_a_particular_action: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::prot_against_an_indiv_who_uses_a_shared_accnt_falsely_denying_having_perfd_a_particular_action::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `prot_against_an_indiv_who_uses_a_shared_accnt_falsely_denying_having_perfd_a_particular_action` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61887
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::prot_against_an_indiv_who_uses_a_shared_accnt_falsely_denying_having_perfd_a_particular_action {
  ora_secured_setup { "prot_against_an_indiv_who_uses_a_shared_accnt_falsely_denying_having_perfd_a_particular_action on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
