#
# ora_secured::controls::protect_audit_tools_from_unauthorized_deletion
#
# @summary Review access permissions to tools used to view or modify audit log data.
# These tools may include the DBMS itself or tools external to the database.
# 
# If appropriate permissions and access controls are not applied to prevent unauthorized deletion of these tools, this is a finding.
# 
# Add or modify access controls and permissions to tools used to view or modify audit log data. Only authorized personnel must be able to delete these tools.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::protect_audit_tools_from_unauthorized_deletion: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::protect_audit_tools_from_unauthorized_deletion::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `protect_audit_tools_from_unauthorized_deletion` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61663
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::protect_audit_tools_from_unauthorized_deletion {
  ora_secured_setup { "protect_audit_tools_from_unauthorized_deletion on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
