#
# ora_secured::controls::prov_cap_to_autom_proc_audit_recs_for_events_of_interest_based_upon_selectable_event_criteria
#
# @summary Review the system (OS, applications external to Oracle, and/or a separate log aggregation and query server) to determine whether it provides the ability to automatically process audit records for events based on selectable event criteria.
# If the system does not provide these abilities, they may be handled by a separate application.
# 
# If the ability to automatically process audit records for events based on selectable event criteria does not exist, this is a finding.
# 
# Utilize a tool, application or service that provides the ability to automatically process audit records for events based on selectable event criteria.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::prov_cap_to_autom_proc_audit_recs_for_events_of_interest_based_upon_selectable_event_criteria: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::prov_cap_to_autom_proc_audit_recs_for_events_of_interest_based_upon_selectable_event_criteria::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `prov_cap_to_autom_proc_audit_recs_for_events_of_interest_based_upon_selectable_event_criteria` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61649
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::prov_cap_to_autom_proc_audit_recs_for_events_of_interest_based_upon_selectable_event_criteria {
  ora_secured_setup { "prov_cap_to_autom_proc_audit_recs_for_events_of_interest_based_upon_selectable_event_criteria on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
