#
# ora_secured::controls::provide_an_audit_log_reduction_capability
#
# @summary Verify that audit reduction capabilities are in place for the Oracle audit data.
# Since Oracle has no reduction capability per se, a third-party tool or in-house-developed software must be in place to provide this functionality.
# 
# If this capability has not been implemented, this is a finding.
# 
# Deploy software capable of performing audit data reduction.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::provide_an_audit_log_reduction_capability: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::provide_an_audit_log_reduction_capability::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `provide_an_audit_log_reduction_capability` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61813
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::provide_an_audit_log_reduction_capability {
  ora_secured_setup { "provide_an_audit_log_reduction_capability on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
