#
# ora_secured::controls::remote_administrative_access_to_the_database_must_be_monitored_by_the_isso_or_issm
#
# @summary If remote administrative access to the database is prohibited and is disabled, this check is not a finding.
# Review policy, procedure and evidence of implementation for monitoring of remote administrative access to the database.
# 
# If monitoring procedures for remote administrative access are not documented or implemented, this is a finding.
# 
# Develop, document and implement policy and procedures to monitor remote administrative access to the DBMS.
# 
# The automated generation of a log report with automatic dissemination to the ISSO/ISSM may be used.
# 
# Require and store an acknowledgement of receipt and confirmation of review for the log report.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::remote_administrative_access_to_the_database_must_be_monitored_by_the_isso_or_issm: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::remote_administrative_access_to_the_database_must_be_monitored_by_the_isso_or_issm::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `remote_administrative_access_to_the_database_must_be_monitored_by_the_isso_or_issm` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61493
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::remote_administrative_access_to_the_database_must_be_monitored_by_the_isso_or_issm {
  ora_secured_setup { "remote_administrative_access_to_the_database_must_be_monitored_by_the_isso_or_issm on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
