#
# ora_secured::controls::remote_database_or_other_external_access_must_use_fully_qualified_names
#
# @summary From SQL*Plus:
# select value from v$parameter where name = 'global_names';
# 
# If the value returned is FALSE, this is a finding.
# 
# 
#   alter system set global_names = TRUE scope = spfile;
# 
# Note: This parameter, if changed, will affect all currently defined Oracle database links.
# 
# The above SQL*Plus command will set the parameter to take effect at next system startup.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::remote_database_or_other_external_access_must_use_fully_qualified_names: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::remote_database_or_other_external_access_must_use_fully_qualified_names::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `remote_database_or_other_external_access_must_use_fully_qualified_names` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61529
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::remote_database_or_other_external_access_must_use_fully_qualified_names {
  ora_secured_setup { "remote_database_or_other_external_access_must_use_fully_qualified_names on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
