#
# ora_secured::controls::remote_dbms_administration_must_be_documented_and_authorized_or_disabled
#
# @summary Review the System Security Plan for authorization, assignments and usage procedures for remote DBMS administration.
# If remote administration of the DBMS is not documented or poorly documented, this is a finding.
# 
# If remote administration of the DBMS is not authorized and not disabled, this is a finding.
# 
# If remote administration is to be performed from outside the DoDIN, but is not done via an approved and properly configured VPN, this is a finding.
# 
# Disable remote administration of the DBMS where not required.
# 
# Where remote administration of the DBMS is required, develop, document and implement policy and procedures on its use.
# 
# Assign remote administration privileges to ISSO-authorized personnel only.
# 
# Document assignments in the System Security Plan.
# 
# Where remote administration is to be performed from outside the DoDIN, configure an approved VPN client for this purpose.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::remote_dbms_administration_must_be_documented_and_authorized_or_disabled: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::remote_dbms_administration_must_be_documented_and_authorized_or_disabled::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `remote_dbms_administration_must_be_documented_and_authorized_or_disabled` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61523
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::remote_dbms_administration_must_be_documented_and_authorized_or_disabled {
  ora_secured_setup { "remote_dbms_administration_must_be_documented_and_authorized_or_disabled on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
