#
# ora_secured::controls::replication_accounts_must_not_be_granted_dba_privileges
#
# @summary If a review of the System Security Plan confirms the use of replication is not required, not permitted and the database is not configured for replication, this check is not a finding.
# If any replication accounts are assigned DBA roles or roles with DBA privileges, this is a finding.
# 
# Restrict privileges assigned to replication accounts to the fewest possible privileges.
# 
# Remove DBA roles from replication accounts.
# 
# Create and use custom replication accounts assigned least privileges for supporting replication operations.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::replication_accounts_must_not_be_granted_dba_privileges: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::replication_accounts_must_not_be_granted_dba_privileges::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `replication_accounts_must_not_be_granted_dba_privileges` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61513
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::replication_accounts_must_not_be_granted_dba_privileges {
  ora_secured_setup { "replication_accounts_must_not_be_granted_dba_privileges on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
