#
# ora_secured::controls::sec_return_server_release_banner_is_set_to_false
#
# @summary The information about patch/update release number provides information about the
# exact patch/update release that is currently running on the database. This is
# sensitive information that should not be revealed to anyone who requests it.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 2.2.15
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 2.2.14
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 2.2.13
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 2.2.13
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::sec_return_server_release_banner_is_set_to_false: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::sec_return_server_release_banner_is_set_to_false::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `sec_return_server_release_banner_is_set_to_false` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::sec_return_server_release_banner_is_set_to_false () {
  $sid = $title
  $unique = ora_secured::random_id(6)

  ora_secured_setup { "sec_return_server_release_banner_is_set_to_false on ${sid}":
    ensure => 'present',
  }
  -> ora_secured::internal::parameter { "SEC_RETURN_SERVER_RELEASE_BANNER@${sid}@${unique}":
    value => 'FALSE',
  }
}
