#
# ora_secured::controls::sensitive_data_strd_in_db_must_be_idntfd_in_sys_sec_plan_and_ais_functional_arch_doc
#
# @summary If no sensitive or classified data is stored in the database, listed in the System Security Plan and listed in the AIS Functional Architecture documentation, this check is not a finding.
# Review AIS Functional Architecture documentation for the DBMS and note any sensitive data that is identified.
# 
# Review database table column data or descriptions that indicate sensitive data.
# 
# For example, a data column labeled "SSN" could indicate social security numbers are stored in the column.
# 
# Question the ISSO or DBA where any questions arise.
# 
# General categories of sensitive data requiring identification include any personal data (health, financial, social security number and date of birth), proprietary or financially sensitive business data or data that might be classified.
# 
# If any data is considered sensitive and is not documented in the AISFA, this is a finding.
# 
# Include identification of any sensitive data in the AIS Functional Architecture and the System Security Plan.
# 
# Include data that appear to be sensitive with a discussion as to why it is not marked as such.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::sensitive_data_strd_in_db_must_be_idntfd_in_sys_sec_plan_and_ais_functional_arch_doc: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::sensitive_data_strd_in_db_must_be_idntfd_in_sys_sec_plan_and_ais_functional_arch_doc::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `sensitive_data_strd_in_db_must_be_idntfd_in_sys_sec_plan_and_ais_functional_arch_doc` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61503
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::sensitive_data_strd_in_db_must_be_idntfd_in_sys_sec_plan_and_ais_functional_arch_doc {
  ora_secured_setup { "sensitive_data_strd_in_db_must_be_idntfd_in_sys_sec_plan_and_ais_functional_arch_doc on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
