#
# ora_secured::controls::set_the_maximum_number_of_consecutive_invalid_logon_attempts_to_three
#
# @summary The limit on the number of consecutive failed logon attempts is defined in the profile assigned to a user.
# Check the FAILED_LOGIN_ATTEMPTS value assigned to the profiles returned from this query:
# SQL>SELECT PROFILE, RESOURCE_NAME, LIMIT FROM DBA_PROFILES;
# 
# Check the setting for FAILED_LOGIN_ATTEMPTS - this is the number of consecutive failed logon attempts before locking the Oracle user account. If the value is greater than three on any of the profiles, this is a finding.
# 
# 
# Configure the DBMS setting to specify the maximum number of consecutive failed logon attempts to three (or less):
# ALTER PROFILE {PROFILE_NAME} LIMIT FAILED_LOGIN_ATTEMPTS 3;
# 
# (ORA_STIG_PROFILE is available in DBA_PROFILES, starting with Oracle 12.1.0.2. Note: It remains necessary to create a customized replacement for the password validation function, ORA12C_STRONG_VERIFY_FUNCTION, if relying on this technique to verify password complexity.)
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::set_the_maximum_number_of_consecutive_invalid_logon_attempts_to_three: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::set_the_maximum_number_of_consecutive_invalid_logon_attempts_to_three::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `set_the_maximum_number_of_consecutive_invalid_logon_attempts_to_three` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61605
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::set_the_maximum_number_of_consecutive_invalid_logon_attempts_to_three {
  ora_secured_setup { "set_the_maximum_number_of_consecutive_invalid_logon_attempts_to_three on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
