#
# ora_secured::controls::single_database_connection_configuration_file_must_not_be_used_to_configure_all_database_clients
#
# @summary Review procedures for providing database connection information to users/user workstations.
# If procedures do not indicate or implement restrictions to connections required by the particular user, this is a finding.
# 
# Note: This check is specific for the DBMS host system and not directed at client systems (client systems are included in the Application STIG/Checklist); however, detection of unauthorized client connections to the DBMS host system obtained through log files should be performed regularly and documented where authorized.
# 
# Implement procedures to supply database connection information to only those databases authorized for the user.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::single_database_connection_configuration_file_must_not_be_used_to_configure_all_database_clients: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::single_database_connection_configuration_file_must_not_be_used_to_configure_all_database_clients::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `single_database_connection_configuration_file_must_not_be_used_to_configure_all_database_clients` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61583
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::single_database_connection_configuration_file_must_not_be_used_to_configure_all_database_clients {
  ora_secured_setup { "single_database_connection_configuration_file_must_not_be_used_to_configure_all_database_clients on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
