#
# ora_secured::controls::supp_org_reqs_to_prhbt_pwd_reuse_for_org_def_number_of_generations
#
# @summary If all user accounts are authenticated by the OS or an enterprise-level authentication/access mechanism, and not by Oracle, this is not a finding.
# For each profile that can be applied to accounts where authentication is under Oracle's control, determine the password reuse rule, if any, that is in effect:
# SELECT * FROM SYS.DBA_PROFILES 
# WHERE RESOURCE_NAME IN ('PASSWORD_REUSE_MAX', 'PASSWORD_REUSE_TIME')
# [AND PROFILE NOT IN (<list of non-applicable profiles>)]
# ORDER BY PROFILE, RESOURCE_NAME;
# Bearing in mind that a profile can inherit from another profile, and the root profile is called DEFAULT, determine the value of the PASSWORD_REUSE_MAX effective for each profile.
# 
# If, for any profile, the PASSWORD_REUSE_MAX value does not enforce the DoD-defined minimum number of password changes before a password may be repeated (five or greater), this is a finding.
# 
# PASSWORD_REUSE_MAX is effective if and only if PASSWORD_REUSE_TIME is specified, so if both are UNLIMITED, this is a finding.
# 
# If all user accounts are authenticated by the OS or an enterprise-level authentication/access mechanism, and not by Oracle, no fix to the DBMS is required.
# 
# If any user accounts are managed by Oracle:  For each profile, set the PASSWORD_REUSE_MAX to enforce the DoD-defined minimum number of password changes before a password may be repeated (five or greater).
# 
# PASSWORD_REUSE_MAX is effective if and only if PASSWORD_REUSE_TIME is specified, so ensure also that it has a meaningful value.  Since the minimum password lifetime is 1 day, the smallest meaningful value is the same as the PASSWORD_REUSE_MAX value.
# 
# Using PPPPPP as an example, the statement to do this is:
# ALTER PROFILE PPPPPP LIMIT PASSWORD_REUSE_MAX 5 PASSWORD_REUSE_TIME 5;
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::supp_org_reqs_to_prhbt_pwd_reuse_for_org_def_number_of_generations: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::supp_org_reqs_to_prhbt_pwd_reuse_for_org_def_number_of_generations::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `supp_org_reqs_to_prhbt_pwd_reuse_for_org_def_number_of_generations` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61721
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::supp_org_reqs_to_prhbt_pwd_reuse_for_org_def_number_of_generations {
  ora_secured_setup { "supp_org_reqs_to_prhbt_pwd_reuse_for_org_def_number_of_generations on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
