#
# ora_secured::controls::supp_org_reqs_to_spec_prhbt_or_rstrct_use_of_unauth_funcs_ports_protocols_and_or_services
#
# @summary Review the DBMS settings for functions, ports, protocols, and services that are not approved.
# If any are found, this is a finding.
# 
# (For definitive information on Ports, Protocols and Services Management (PPSM), refer to http://www.disa.mil/Services/Network-Services/Enterprise-Connections/PPSM)
# 
# - - - - -
# In the Oracle database, the communications with the database and incoming requests are performed by the Oracle Listener.  The Oracle Listener listens on a specific port or ports for connections to a specific database.  The Oracle Listener has configuration files located in the $ORACLE_HOME/network/admin directory.  To check the ports and protocols in use, go to  that directory and review the SQLNET.ora, LISTENER.ora, and the TNSNAMES.ora.  If protocols or ports are in use that are not authorized, this is a finding.
# 
# Disable functions, ports, protocols, and services that are not approved.
# 
# - - - - -
# Change the SQLNET.ora, LISTENER.ora, and TNSNAMES.ora files to reflect the proper use of ports, protocols, and services that are approved at the site.
# 
# If changes to the Listener are made, the files associated with the Listener must be reloaded.  Do that by issuing the following commands at the Unix/Linux or Windows prompt.
# First - issue the command to see what the current status is
# $ lsnrctl stat
# Then load the new file that was corrected to reflect site-specific requirements.
# $ lsnrctl reload
# Then check the status again to see that the changes have taken place.
# $ lsnrctl stat
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::supp_org_reqs_to_spec_prhbt_or_rstrct_use_of_unauth_funcs_ports_protocols_and_or_services: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::supp_org_reqs_to_spec_prhbt_or_rstrct_use_of_unauth_funcs_ports_protocols_and_or_services::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `supp_org_reqs_to_spec_prhbt_or_rstrct_use_of_unauth_funcs_ports_protocols_and_or_services` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61687
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::supp_org_reqs_to_spec_prhbt_or_rstrct_use_of_unauth_funcs_ports_protocols_and_or_services {
  ora_secured_setup { "supp_org_reqs_to_spec_prhbt_or_rstrct_use_of_unauth_funcs_ports_protocols_and_or_services on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
