#
# ora_secured::controls::supp_taking_org_def_lst_of_least_disruptive_actions_to_term_suspicious_events
#
# @summary Obtain the CC/S/A/FA's list of suspicious event types and the actions to be taken in response, ordered from least disruptive to last resort.
# If the list does not exist, this is a finding.
# 
# For each event type in the list, review the measures in place in the DBMS/database configuration that are designed to detect and/or counter the event.  (Alerting an administrator or operator to the problem is a valid measure.)
# 
# If, for any event type defined in the list, no means of detecting the event exists, this is a finding.
# 
# For each event type where an automatic countermeasure is defined, verify that its implementation is congruent with the list of defined actions.  If not, this is a finding.
# 
# Verify that administrators/operators are familiar with the list and the notification mechanism and are equipped to follow the instructions in the list.  If not, this is a finding.
# 
# If the list does not exist, create it.
# 
# For any event type defined in the list where no means of detecting the event exists, either create the means of detection or modify the list.
# 
# For each event type where an automatic countermeasure is defined but its implementation differs from its description in the list, either modify the countermeasure or amend the list.
# 
# If any administrators/operators are unfamiliar with the list or the notification mechanism, train them.
# 
# If any administrators/operators are not equipped to follow the instructions in the list, provide them with the means to do so.
# 
# Ensure the list is incorporated into, or referenced by, the System Security Plan.
# 
# Note that Oracle Audit Vault and Oracle Database Vault are optional products that can be of considerable use in implementing active protection measures of this kind.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::supp_taking_org_def_lst_of_least_disruptive_actions_to_term_suspicious_events: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::supp_taking_org_def_lst_of_least_disruptive_actions_to_term_suspicious_events::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `supp_taking_org_def_lst_of_least_disruptive_actions_to_term_suspicious_events` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61795
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::supp_taking_org_def_lst_of_least_disruptive_actions_to_term_suspicious_events {
  ora_secured_setup { "supp_taking_org_def_lst_of_least_disruptive_actions_to_term_suspicious_events on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
