#
# ora_secured::controls::system_privileges_must_not_be_granted_to_public
#
# @summary From SQL*Plus:
# select privilege from dba_sys_privs where grantee = 'PUBLIC';
# 
# If any records are returned, this is a finding.
# 
# Revoke any system privileges assigned to PUBLIC:
# 
# 
#   revoke [system privilege] from PUBLIC;
# 
# Replace [system privilege] with the named system privilege.
# 
# Note:  System privileges are not granted to PUBLIC by default and would indicate a custom action.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::system_privileges_must_not_be_granted_to_public: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::system_privileges_must_not_be_granted_to_public::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `system_privileges_must_not_be_granted_to_public` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61435
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::system_privileges_must_not_be_granted_to_public {
  ora_secured_setup { "system_privileges_must_not_be_granted_to_public on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
