#
# ora_secured::controls::uniquely_identify_and_authenticate_non_org_users_or_procs_acting_on_behalf_of_non_org_users
#
# @summary Review DBMS settings to determine whether non-organizational users are uniquely identified and authenticated when logging onto the system.
# If non-organizational users are not uniquely identified and authenticated, this is a finding.
# 
# Configure DBMS settings to uniquely identify and authenticate all non-organizational users who log onto the system.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::uniquely_identify_and_authenticate_non_org_users_or_procs_acting_on_behalf_of_non_org_users: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::uniquely_identify_and_authenticate_non_org_users_or_procs_acting_on_behalf_of_non_org_users::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `uniquely_identify_and_authenticate_non_org_users_or_procs_acting_on_behalf_of_non_org_users` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61881
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::uniquely_identify_and_authenticate_non_org_users_or_procs_acting_on_behalf_of_non_org_users {
  ora_secured_setup { "uniquely_identify_and_authenticate_non_org_users_or_procs_acting_on_behalf_of_non_org_users on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
