#
# ora_secured::controls::use_of_the_dbms_software_installation_account_must_be_restricted
#
# @summary Review system documentation to identify the installation account.
# Verify whether the account is used for anything involving interactive activity beyond DBMS software installation, upgrade, and maintenance actions.
# 
# If the account is used for anything involving interactive activity beyond DBMS software installation, upgrade, and maintenance actions, this is a finding.
# 
# Restrict interactive use of the DBMS software installation account to DBMS software installation, upgrade, and maintenance actions only.
# 
# If possible, disable installation accounts when authorized actions are not being performed. Otherwise, disable the use of the account(s) for interactive activity.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::use_of_the_dbms_software_installation_account_must_be_restricted: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::use_of_the_dbms_software_installation_account_must_be_restricted::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `use_of_the_dbms_software_installation_account_must_be_restricted` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61865
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::use_of_the_dbms_software_installation_account_must_be_restricted {
  ora_secured_setup { "use_of_the_dbms_software_installation_account_must_be_restricted on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
