#
# ora_secured::controls::verify_account_lockouts_persist_until_reset_by_an_administrator
#
# @summary The account lockout duration is defined in the profile assigned to a user.
# To see what profile is assigned to a user, enter the query:
# 
# SQL>SELECT profile FROM dba_users WHERE username = '<username>'
# 
# This will return the profile name assigned to that user.
# 
# The user profile, ORA_STIG_PROFILE, has been provided (starting with Oracle 12.1.0.2) to satisfy the STIG requirements pertaining to the profile parameters. Oracle recommends that this profile be customized with any site-specific requirements and assigned to all users where applicable.  Note: It remains necessary to create a customized replacement for the password validation function, ORA12C_STRONG_VERIFY_FUNCTION, if relying on this technique to verify password complexity.
# 
# Now check the values assigned to the profile returned from the query above:
# 
# column profile format a20
# column limit format a20
# SQL>SELECT PROFILE, RESOURCE_NAME, LIMIT FROM DBA_PROFILES WHERE PROFILE = 'ORA_STIG_PROFILE';
# 
# Check the settings for password_lock_time - this specifies how long to lock the account after the number of consecutive failed logon attempts reaches the limit. If the value is not UNLIMITED, this is a finding.
# 
# Configure the DBMS settings to specify indefinite lockout duration:
# ALTER PROFILE ORA_STIG_PROFILE LIMIT PASSWORD_LOCK_TIME UNLIMITED;
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::verify_account_lockouts_persist_until_reset_by_an_administrator: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::verify_account_lockouts_persist_until_reset_by_an_administrator::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `verify_account_lockouts_persist_until_reset_by_an_administrator` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61603
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::verify_account_lockouts_persist_until_reset_by_an_administrator {
  ora_secured_setup { "verify_account_lockouts_persist_until_reset_by_an_administrator on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
