#
# ora_secured::controls::verify_there_have_not_been_unauthorized_changes_to_the_dbms_software_and_information
#
# @summary Verify the DBMS system initialization/parameter files and software is  included in the configuration of any  third-party software or custom scripting at the OS level to perform integrity verification.
# If neither a third-party application nor the OS is performing integrity verification of DBMS system files, this is a finding.
# 
# Utilize the OS or a third-party product to perform file verification of DBMS system file integrity.
# 
# (Using Oracle Configuration Manager with Enterprise Manager, configured to perform this verification, is one possible way of satisfying this requirement.)
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::verify_there_have_not_been_unauthorized_changes_to_the_dbms_software_and_information: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::verify_there_have_not_been_unauthorized_changes_to_the_dbms_software_and_information::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `verify_there_have_not_been_unauthorized_changes_to_the_dbms_software_and_information` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61787
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::verify_there_have_not_been_unauthorized_changes_to_the_dbms_software_and_information {
  ora_secured_setup { "verify_there_have_not_been_unauthorized_changes_to_the_dbms_software_and_information on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
