#
# See the file "LICENSE" for the full license governing this code.
#
#
# Set the specific property of a profile
#
# $title      iprofile setting including the sid e.g. AUDIT_SYS_OPERATIONS@SID
# $value      Value to set the paremeter ro
# $exclude    the profiles to exclude e.g. not apply the rule to
#
#
define ora_secured::internal::profile_setting (
  Any    $value,
  Array  $exclude,
  Array  $only,
) {
  $split    = $title.split('@')
  $property = $split[0]
  $sid      = $split[1]

  # C## Profiles can only be altered on CDB
  if ! ora_config::is_root_db($sid) {
      $exclude_profile = ora_config::on_sid($facts['ora_global_profiles'], $sid)
  } else {
      $exclude_profile = ''
  }

  if $only == [] {
    $profiles_to_check = ora_config::on_sid($facts['ora_profiles'], $sid) - $exclude - $exclude_profile
  } else {
    $profiles_to_check = $only
  }

  #
  # Check all accounts with a default password and set it to an unknown non-default value
  #
  $profiles_to_check.each |$profile| {
    $full_name = "Ora_profile[${profile}@${sid}]${property}"
    resource_value { $full_name:
      value          => $value,
      allow_create   => true,
      allow_redefine => true,
    }
  }
}
