#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::validators::alter_system_action_audit_is_enabled (
  Boolean   $skip      = ora_secured::lookup_setting('skip', false),
  String[1] $report_as = ora_secured::lookup_setting('report_as', 'warning'),
) {
  ora_secured_setup { "alter_system_action_audit_is_enabled validation on ${title}":
    ensure => 'present',
  }
  $query = @(QUERY)
    WITH
      CIS_AUDIT(AUDIT_OPTION) AS
        (
          SELECT * FROM TABLE(
                                DBMSOUTPUT_LINESARRAY( 'ALTER SYSTEM' )
                             )
        ),
      AUDIT_ENABLED AS
        (
          SELECT DISTINCT AUDIT_OPTION
            FROM AUDIT_UNIFIED_POLICIES AUD
           WHERE AUD.AUDIT_OPTION IN ( 'ALTER SYSTEM' )
             AND AUD.AUDIT_OPTION_TYPE = 'STANDARD ACTION'
             AND EXISTS (SELECT *
                           FROM AUDIT_UNIFIED_ENABLED_POLICIES ENABLED
                          WHERE ENABLED.SUCCESS = 'YES'
                            AND ENABLED.FAILURE = 'YES'
                            AND ENABLED.ENABLED_OPTION = 'BY USER'
                            AND ENABLED.ENTITY_NAME = 'ALL USERS'
                            AND ENABLED.POLICY_NAME = AUD.POLICY_NAME)
        )
      SELECT C.AUDIT_OPTION
        FROM CIS_AUDIT C
               LEFT JOIN AUDIT_ENABLED E
          ON C.AUDIT_OPTION = E.AUDIT_OPTION
       WHERE E.AUDIT_OPTION IS NULL
    |-QUERY

  ora_secured_setup { "alter_system_action_audit_is_enabled validation on ${title}":
    ensure => present,
  }
  -> ora_validation { "Auditing is enabled for 'ALTER SYSTEM' action on ${title}":
    check                   => $query,
    expected_number_of_rows => 0,
    report_as               => $report_as,
    sid                     => $title,
    skip                    => $skip,
    control                 => easy_type::current_control(),
    fail_message            => "Auditing should be enabled for 'ALTER SYSTEM' action, but it's NOT",
  }
}
