#
# ora_secured::controls::apps_must_obscure_feedback_of_auth_info_during_auth_proc_to_prot_info_frm_possible_exploitation_u
#
# @summary Interview the DBA to determine if any applications that access the database allow for entry of the account name and password on the command line.
# If any do, determine whether these applications obfuscate authentication data.  If they do not, this is a finding.
# 
# Configure or modify applications to prohibit display of passwords in clear text on the command line.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::apps_must_obscure_feedback_of_auth_info_during_auth_proc_to_prot_info_frm_possible_exploitation_u: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::apps_must_obscure_feedback_of_auth_info_during_auth_proc_to_prot_info_frm_possible_exploitation_u::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `apps_must_obscure_feedback_of_auth_info_during_auth_proc_to_prot_info_frm_possible_exploitation_u` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61843
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::apps_must_obscure_feedback_of_auth_info_during_auth_proc_to_prot_info_frm_possible_exploitation_u {
  ora_secured_setup { "apps_must_obscure_feedback_of_auth_info_during_auth_proc_to_prot_info_frm_possible_exploitation_u on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
