#
# ora_secured::controls::oracle_software_must_be_evaluated_and_patched_against_newly_found_vulnerabilities
#
# @summary When the Quarterly CPU is released, check the CPU Notice and note the specific patch number for the system.
# Then, issue the following command:
# 
# SELECT patch_id, version, action, status, description from dba_registry_sqlpatch;
# 
# This will generate the patch levels for the home and any specific patches that have been applied to it.
# 
# If the currently installed patch levels are lower than the latest, this is a finding.
# 
# Follow the process below to apply the security patch.
# 
# Log on to My Oracle Support.
# 
# Select patches and download the specific patch number and corresponding MD5 checksum. Once the patch is downloaded to the server, check the MD5 checksum to make sure the patch is valid.
# 
# To check the MD5 Checksum in Linux/UNIX, the command is:
# $md5sum absolute_path_of_file_name - file_name is the complete location of the downloaded file.
# $md5sum /home/oracle/test.zip
# a34d8cd98f00cf24e9800998ecf823e4 /home/oracle/test.zip
# 
# Once the checksum is validated, apply the patch:
# $ cd $ORACLE_HOME
# $ opatch apply
# 
# Check that the patch was applied and the inventory was updated with the following command (UNIX/Linux):
# $ opatch lsinventory -detail
# 
# Windows:
# > opatch lsinventory –detail
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::oracle_software_must_be_evaluated_and_patched_against_newly_found_vulnerabilities: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::oracle_software_must_be_evaluated_and_patched_against_newly_found_vulnerabilities::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `oracle_software_must_be_evaluated_and_patched_against_newly_found_vulnerabilities` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61539
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::oracle_software_must_be_evaluated_and_patched_against_newly_found_vulnerabilities {
  ora_secured_setup { "oracle_software_must_be_evaluated_and_patched_against_newly_found_vulnerabilities on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
